<?php


if (!defined('ABSPATH')) {
    exit;
}

if (!class_exists('Ecofa_Elementor')) :

    /**
     * The Ecofa Elementor Integration class
     */
    class Ecofa_Elementor {
        private $suffix = '';

        public function __construct() {
            $this->suffix = (defined('SCRIPT_DEBUG') && SCRIPT_DEBUG) ? '' : '.min';

            add_action('wp', [$this, 'register_auto_scripts_frontend']);
            add_action('elementor/init', array($this, 'add_category'));
            add_action('wp_enqueue_scripts', [$this, 'add_scripts'], 15);
            add_action('elementor/widgets/register', array($this, 'include_widgets'));
            add_action('elementor/frontend/after_enqueue_scripts', [$this, 'add_js']);

            // Custom Animation Scroll
            add_filter('elementor/controls/animations/additional_animations', [$this, 'add_animations_scroll']);

            // Elementor Fix Noitice WooCommerce
            add_action('elementor/editor/before_enqueue_scripts', array($this, 'woocommerce_fix_notice'));

            // Backend
            add_action('elementor/editor/after_enqueue_styles', [$this, 'add_style_editor'], 99);

            // Add Icon Custom
            add_action('elementor/icons_manager/native', [$this, 'add_icons_native']);
            add_action('elementor/controls/controls_registered', [$this, 'add_icons']);

            // Add Breakpoints
            add_action('wp_enqueue_scripts', 'ecofa_elementor_breakpoints', 9999);

            if (!ecofa_is_elementor_pro_activated()) {
                require trailingslashit(get_template_directory()) . 'inc/elementor/class-custom-css.php';
                require trailingslashit(get_template_directory()) . 'inc/elementor/class-section-sticky.php';
                if (is_admin()) {
                    add_action('manage_elementor_library_posts_columns', [$this, 'admin_columns_headers']);
                    add_action('manage_elementor_library_posts_custom_column', [$this, 'admin_columns_content'], 10, 2);
                }
            }

            add_filter('elementor/fonts/additional_fonts', [$this, 'additional_fonts']);

        }

        public function additional_fonts($fonts) {
            $fonts["Instrument Sans"] = 'system';
            return $fonts;
        }

        public function admin_columns_headers($defaults) {
            $defaults['shortcode'] = esc_html__('Shortcode', 'ecofa');

            return $defaults;
        }

        public function admin_columns_content($column_name, $post_id) {
            if ('shortcode' === $column_name) {
                ob_start();
                ?>
                <input class="elementor-shortcode-input" type="text" readonly onfocus="this.select()" value="[hfe_template id='<?php echo esc_attr($post_id); ?>']"/>
                <?php
                ob_get_contents();
            }
        }

        public function add_js() {
            global $ecofa_version;
            wp_enqueue_script('ecofa-elementor-frontend', get_theme_file_uri('/assets/js/elementor-frontend.js'), [], $ecofa_version);
        }

        public function add_style_editor() {
            global $ecofa_version;
            wp_enqueue_style('ecofa-icon', get_template_directory_uri() . '/assets/css/icons.css', '', $ecofa_version);
        }

        public function add_scripts() {
            global $ecofa_version;
            $suffix = (defined('SCRIPT_DEBUG') && SCRIPT_DEBUG) ? '' : '.min';
            wp_enqueue_style('ecofa-elementor', get_template_directory_uri() . '/assets/css/elementor.css', '', $ecofa_version);
            wp_style_add_data('ecofa-elementor', 'rtl', 'replace');

            // Add Scripts
            wp_register_script('tweenmax', get_theme_file_uri('/assets/js/libs/TweenMax.min.js'), array('jquery'), '1.11.1');

            if (ecofa_elementor_check_type('animated-bg-parallax')) {
                wp_enqueue_script('tweenmax');
                wp_enqueue_script('jquery-panr', get_theme_file_uri('/assets/js/libs/jquery-panr' . $suffix . '.js'), array('jquery'), '0.0.1');
            }
        }

        public function register_auto_scripts_frontend() {
            global $ecofa_version;
            wp_register_script('ecofa-elementor-accordion', get_theme_file_uri('/assets/js/elementor/accordion.js'), array('jquery','elementor-frontend'), $ecofa_version, true);
            wp_register_script('ecofa-elementor-brand', get_theme_file_uri('/assets/js/elementor/brand.js'), array('jquery','elementor-frontend'), $ecofa_version, true);
            wp_register_script('ecofa-elementor-countdown', get_theme_file_uri('/assets/js/elementor/countdown.js'), array('jquery','elementor-frontend'), $ecofa_version, true);
            wp_register_script('ecofa-elementor-give-form-grid', get_theme_file_uri('/assets/js/elementor/give-form-grid.js'), array('jquery','elementor-frontend'), $ecofa_version, true);
            wp_register_script('ecofa-elementor-header-carousel', get_theme_file_uri('/assets/js/elementor/header-carousel.js'), array('jquery','elementor-frontend'), $ecofa_version, true);
            wp_register_script('ecofa-elementor-history-carousel', get_theme_file_uri('/assets/js/elementor/history-carousel.js'), array('jquery','elementor-frontend'), $ecofa_version, true);
            wp_register_script('ecofa-elementor-image-carousel', get_theme_file_uri('/assets/js/elementor/image-carousel.js'), array('jquery','elementor-frontend'), $ecofa_version, true);
            wp_register_script('ecofa-elementor-image-gallery', get_theme_file_uri('/assets/js/elementor/image-gallery.js'), array('jquery','elementor-frontend'), $ecofa_version, true);
            wp_register_script('ecofa-elementor-image-panorama', get_theme_file_uri('/assets/js/elementor/image-panorama.js'), array('jquery','elementor-frontend'), $ecofa_version, true);
            wp_register_script('ecofa-elementor-link-showcase', get_theme_file_uri('/assets/js/elementor/link-showcase.js'), array('jquery','elementor-frontend'), $ecofa_version, true);
            wp_register_script('ecofa-elementor-posts-grid', get_theme_file_uri('/assets/js/elementor/posts-grid.js'), array('jquery','elementor-frontend'), $ecofa_version, true);
            wp_register_script('ecofa-elementor-protect', get_theme_file_uri('/assets/js/elementor/protect.js'), array('jquery','elementor-frontend'), $ecofa_version, true);
            wp_register_script('ecofa-elementor-slider-scrolling', get_theme_file_uri('/assets/js/elementor/slider-scrolling.js'), array('jquery','elementor-frontend'), $ecofa_version, true);
            wp_register_script('ecofa-elementor-team-box', get_theme_file_uri('/assets/js/elementor/team-box.js'), array('jquery','elementor-frontend'), $ecofa_version, true);
            wp_register_script('ecofa-elementor-testimonial', get_theme_file_uri('/assets/js/elementor/testimonial.js'), array('jquery','elementor-frontend'), $ecofa_version, true);
            wp_register_script('ecofa-elementor-testimonial-carousel', get_theme_file_uri('/assets/js/elementor/testimonial-carousel.js'), array('jquery','elementor-frontend'), $ecofa_version, true);
            wp_register_script('ecofa-elementor-video', get_theme_file_uri('/assets/js/elementor/video.js'), array('jquery','elementor-frontend'), $ecofa_version, true);
           
        }

        public function add_category() {
            Elementor\Plugin::instance()->elements_manager->add_category(
                'ecofa-addons',
                array(
                    'title' => esc_html__('Ecofa Addons', 'ecofa'),
                    'icon'  => 'fa fa-plug',
                ), 1);
        }

        public function add_animations_scroll($animations) {
            $animations['Ecofa Animation'] = [
                'opal-move-up'    => 'Move Up',
                'opal-move-down'  => 'Move Down',
                'opal-move-left'  => 'Move Left',
                'opal-move-right' => 'Move Right',
                'opal-flip'       => 'Flip',
                'opal-helix'      => 'Helix',
                'opal-scale-up'   => 'Scale',
                'opal-am-popup'   => 'Popup',
            ];

            return $animations;
        }

        /**
         * @param $widgets_manager Elementor\Widgets_Manager
         */
        public function include_widgets($widgets_manager) {
            require 'base_widgets.php';

            $files_custom = glob(get_theme_file_path('/inc/elementor/custom-widgets/*.php'));
            foreach ($files_custom as $file) {
                if (file_exists($file)) {
                    require_once $file;
                }
            }

            $files = glob(get_theme_file_path('/inc/elementor/widgets/*.php'));
            foreach ($files as $file) {
                if (file_exists($file)) {
                    require_once $file;
                }
            }
        }

        public function woocommerce_fix_notice() {
            if (ecofa_is_woocommerce_activated()) {
                remove_action('woocommerce_cart_is_empty', 'woocommerce_output_all_notices', 5);
                remove_action('woocommerce_shortcode_before_product_cat_loop', 'woocommerce_output_all_notices', 10);
                remove_action('woocommerce_before_shop_loop', 'woocommerce_output_all_notices', 10);
                remove_action('woocommerce_before_single_product', 'woocommerce_output_all_notices', 10);
                remove_action('woocommerce_before_cart', 'woocommerce_output_all_notices', 10);
                remove_action('woocommerce_before_checkout_form', 'woocommerce_output_all_notices', 10);
                remove_action('woocommerce_account_content', 'woocommerce_output_all_notices', 10);
                remove_action('woocommerce_before_customer_login_form', 'woocommerce_output_all_notices', 10);
            }
        }

        public function add_icons( $manager ) {
            $new_icons = json_decode( '{"ecofa-icon-arrow-circle-down":"arrow-circle-down","ecofa-icon-arrow-circle-up":"arrow-circle-up","ecofa-icon-bag":"bag","ecofa-icon-calendar":"calendar","ecofa-icon-check-circle-o":"check-circle-o","ecofa-icon-delivery":"delivery","ecofa-icon-facebook-02":"facebook-02","ecofa-icon-linkedin":"linkedin","ecofa-icon-map-pin-02":"map-pin-02","ecofa-icon-messages2":"messages2","ecofa-icon-phone-02":"phone-02","ecofa-icon-pickup":"pickup","ecofa-icon-play-video-01":"play-video-01","ecofa-icon-play-video":"play-video","ecofa-icon-profile":"profile","ecofa-icon-quotedowncircle":"quotedowncircle","ecofa-icon-search-sm":"search-sm","ecofa-icon-send-1":"send-1","ecofa-icon-subtract":"subtract","ecofa-icon-tag":"tag","ecofa-icon-tick-circle":"tick-circle","ecofa-icon-twitter-01":"twitter-01","ecofa-icon-360":"360","ecofa-icon-add-line":"add-line","ecofa-icon-angle-down":"angle-down","ecofa-icon-angle-left":"angle-left","ecofa-icon-angle-right":"angle-right","ecofa-icon-angle-up":"angle-up","ecofa-icon-caret-circle-down":"caret-circle-down","ecofa-icon-caret-circle-left":"caret-circle-left","ecofa-icon-caret-circle-right":"caret-circle-right","ecofa-icon-caret-circle-up":"caret-circle-up","ecofa-icon-caret-down":"caret-down","ecofa-icon-caret-left":"caret-left","ecofa-icon-caret-right":"caret-right","ecofa-icon-caret-square-down":"caret-square-down","ecofa-icon-caret-square-left":"caret-square-left","ecofa-icon-caret-square-right":"caret-square-right","ecofa-icon-caret-square-up":"caret-square-up","ecofa-icon-caret-up":"caret-up","ecofa-icon-cart-empty":"cart-empty","ecofa-icon-check-circle":"check-circle","ecofa-icon-check-double":"check-double","ecofa-icon-check-square":"check-square","ecofa-icon-chevron-down":"chevron-down","ecofa-icon-chevron-left":"chevron-left","ecofa-icon-chevron-right":"chevron-right","ecofa-icon-chevron-selector-vertical":"chevron-selector-vertical","ecofa-icon-chevron-square-down":"chevron-square-down","ecofa-icon-chevron-up":"chevron-up","ecofa-icon-cloud-download-alt":"cloud-download-alt","ecofa-icon-compare":"compare","ecofa-icon-credit-card":"credit-card","ecofa-icon-dot-circle":"dot-circle","ecofa-icon-edit":"edit","ecofa-icon-envelope":"envelope","ecofa-icon-equalizer-line":"equalizer-line","ecofa-icon-eye-dropper":"eye-dropper","ecofa-icon-eye-evil":"eye-evil","ecofa-icon-eye-slash":"eye-slash","ecofa-icon-eye":"eye","ecofa-icon-file-alt":"file-alt","ecofa-icon-file-archive":"file-archive","ecofa-icon-filter":"filter","ecofa-icon-frown-open":"frown-open","ecofa-icon-frown":"frown","ecofa-icon-gift-card":"gift-card","ecofa-icon-gift":"gift","ecofa-icon-gifts":"gifts","ecofa-icon-home":"home","ecofa-icon-info-circle":"info-circle","ecofa-icon-instagram":"instagram","ecofa-icon-layout-grid":"layout-grid","ecofa-icon-layout-list":"layout-list","ecofa-icon-long-arrow-down":"long-arrow-down","ecofa-icon-long-arrow-left":"long-arrow-left","ecofa-icon-long-arrow-right":"long-arrow-right","ecofa-icon-long-arrow-up":"long-arrow-up","ecofa-icon-marker-pin-01":"marker-pin-01","ecofa-icon-meh-blank":"meh-blank","ecofa-icon-meh-rolling-eyes":"meh-rolling-eyes","ecofa-icon-meh":"meh","ecofa-icon-minus-circle":"minus-circle","ecofa-icon-minus":"minus","ecofa-icon-money-check-alt":"money-check-alt","ecofa-icon-phone":"phone","ecofa-icon-pinterest-p":"pinterest-p","ecofa-icon-plus-circle":"plus-circle","ecofa-icon-plus":"plus","ecofa-icon-quickview":"quickview","ecofa-icon-rating":"rating","ecofa-icon-repeat":"repeat","ecofa-icon-reply-line":"reply-line","ecofa-icon-search-plus":"search-plus","ecofa-icon-share-all":"share-all","ecofa-icon-shopping-bag":"shopping-bag","ecofa-icon-shopping-basket":"shopping-basket","ecofa-icon-shopping-cart":"shopping-cart","ecofa-icon-sign-out-alt":"sign-out-alt","ecofa-icon-smile":"smile","ecofa-icon-spinner-third":"spinner-third","ecofa-icon-spinner":"spinner","ecofa-icon-square-full":"square-full","ecofa-icon-star":"star","ecofa-icon-sync-alt":"sync-alt","ecofa-icon-sync":"sync","ecofa-icon-tachometer-alt":"tachometer-alt","ecofa-icon-times-circle":"times-circle","ecofa-icon-times":"times","ecofa-icon-truck":"truck","ecofa-icon-user":"user","ecofa-icon-wishlist-01":"wishlist-01","ecofa-icon-wishlist-empty":"wishlist-empty","ecofa-icon-wishlist":"wishlist","ecofa-icon-youtube-o":"youtube-o","ecofa-icon-youtube":"youtube"}', true );
			$icons     = $manager->get_control( 'icon' )->get_settings( 'options' );
			$new_icons = array_merge(
				$new_icons,
				$icons
			);
			// Then we set a new list of icons as the options of the icon control
			$manager->get_control( 'icon' )->set_settings( 'options', $new_icons ); 
        }

        public function add_icons_native($tabs) {
            global $ecofa_version;
            $tabs['opal-custom'] = [
                'name'          => 'ecofa-icon',
                'label'         => esc_html__('Ecofa Icon', 'ecofa'),
                'prefix'        => 'ecofa-icon-',
                'displayPrefix' => 'ecofa-icon-',
                'labelIcon'     => 'fab fa-font-awesome-alt',
                'ver'           => $ecofa_version,
                'fetchJson'     => get_theme_file_uri('/inc/elementor/icons.json'),
                'native'        => true,
            ];

            return $tabs;
        }
    }

endif;

return new Ecofa_Elementor();
