<?php
use Elementor\Controls_Manager;
use Elementor\Control_Media;
use Elementor\Group_Control_Border;
use Elementor\Icons_Manager;
use Elementor\Utils;
use Elementor\Widget_Icon_Box;

add_action('elementor/element/icon-box/section_style_content/before_section_end', function ($element, $args) {
    $element->add_responsive_control(
        'align_content',
        [
            'label'     => esc_html__('Alignment Info ', 'ecofa'),
            'type'      => Controls_Manager::CHOOSE,
            'options'   => [
                'flex-start' => [
                    'title' => esc_html__('Left', 'ecofa'),
                    'icon'  => 'eicon-h-align-left',
                ],
                'center'     => [
                    'title' => esc_html__('Center', 'ecofa'),
                    'icon'  => 'eicon-h-align-center',
                ],
                'flex-end'   => [
                    'title' => esc_html__('Right', 'ecofa'),
                    'icon'  => 'eicon-h-align-right',
                ],
            ],
            'default'   => 'center',
            'selectors' => [
                '{{WRAPPER}} .elementor-icon-box-icon .elementor-icon' => 'justify-content: {{VALUE}}',
            ],
        ]
    );
	$element->add_control(
		'icon_box_title_hover',
		[
			'label'     => esc_html__('Color Title Hover', 'ecofa'),
			'type'      => Controls_Manager::COLOR,
			'default'   => '',
			'selectors' => [
				'{{WRAPPER}} .elementor-icon-box-wrapper:hover .elementor-icon-box-content .elementor-icon-box-title' => 'color: {{VALUE}};',
			],
            'separator'    => 'before',
		]
	);
}, 10, 2);

add_action('elementor/element/icon-box/section_style_content/before_section_end', function ($element, $args) {
    $element->add_responsive_control(
        'icon_box_title_margin',
        [
            'label' => esc_html__('Title Margin', 'ecofa'),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', 'em'],
            'selectors' => [
                '{{WRAPPER}} .elementor-icon-box-title' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
            ],
        ]
    );
}, 10, 2);

add_action('elementor/element/icon-box/section_style_content/before_section_end', function ($element, $args) {
    $element->add_responsive_control(
        'icon_box_description_margin',
        [
            'label' => esc_html__('Description Margin', 'ecofa'),
            'type' => Controls_Manager::DIMENSIONS,
            'size_units' => ['px', 'em'],
            'selectors' => [
                '{{WRAPPER}} .elementor-icon-box-description' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
            ],
        ]
    );
}, 10, 2);

add_action('elementor/element/icon-box/section_style_icon/before_section_end', function ($element, $args) {
    $element->add_control(
        'icon_box_color_border',
        [
            'label'     => esc_html__('Color Border', 'ecofa'),
            'type'      => Controls_Manager::COLOR,
            'default'   => '',
            'selectors' => [
                '{{WRAPPER}}.elementor-view-framed .elementor-icon' => 'border-color: {{VALUE}};',
            ],
            'condition' => [
                'view' => 'framed',
            ],
        ]
    );
}, 10, 2);


add_action('elementor/element/icon-box/section_style_icon/before_section_end', function ($element, $args) {
    $element->add_control(
        'icon_box_shape_color',
        [
            'label'     => esc_html__('Color Shape', 'ecofa'),
            'type'      => Controls_Manager::COLOR,
            'default'   => '',
            'selectors' => [
                '{{WRAPPER}}.icon-shape-yes .elementor-icon i:after, {{WRAPPER}}.icon-shape-yes .elementor-icon svg:after' => 'background-color: {{VALUE}};',

            ],
            'condition' => [
                'icon_box_shape' => 'yes',
            ],
        ]
    );
}, 10, 2);

add_action('elementor/element/icon-box/section_style_icon/before_section_end', function ($element, $args) {
    $element->add_control(
        'icon_box_shape_color_hover',
        [
            'label'     => esc_html__('Color Shape Hover', 'ecofa'),
            'type'      => Controls_Manager::COLOR,
            'default'   => '',
            'selectors' => [
                '{{WRAPPER}}.icon-shape-yes:hover .elementor-icon i:after, {{WRAPPER}}.icon-shape-yes:hover .elementor-icon svg:after' => 'background-color: {{VALUE}};',

            ],
            'condition' => [
                'icon_box_shape' => 'yes',
            ],
        ]
    );
}, 10, 2);

add_action('elementor/element/icon-box/section_style_icon/before_section_end', function ($element, $args) {
    $element->add_responsive_control(
        'icon_box_shape_size',
        [
            'label'     => esc_html__('Shape Size', 'ecofa'),
            'type'      => Controls_Manager::SLIDER,
            'range'     => [
                'px' => [
                    'min' => 0,
                    'max' => 150,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}}.icon-shape-yes .elementor-icon i:after, {{WRAPPER}}.icon-shape-yes .elementor-icon svg:after' => 'font-size: {{SIZE}}{{UNIT}}; width: {{SIZE}}{{UNIT}}; height: {{SIZE}}{{UNIT}}',
            ],
            'condition' => [
                'icon_box_shape' => 'yes',
            ],
        ]
    );

}, 10, 2);


add_action('elementor/element/icon-box/section_style_icon/before_section_end', function ($element, $args) {
    $element->add_responsive_control(
        'icon_box_shape_color_right',
        [
            'label'     => esc_html__('Color Shape Top Horizontal', 'ecofa'),
            'type'      => Controls_Manager::SLIDER,
            'size_units'=> ['px', 'em', '%'],
            'range' => [
                'px' => [
                    'min' => -30,
                    'max' => 60,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}}.icon-shape-yes .elementor-icon i:after, {{WRAPPER}}.icon-shape-yes .elementor-icon svg:after' => 'right: {{SIZE}}{{UNIT}};',

            ],
            'condition' => [
                'icon_box_shape' => 'yes',
            ],
        ]
    );
}, 10, 2);

add_action('elementor/element/icon-box/section_style_icon/before_section_end', function ($element, $args) {
    $element->add_responsive_control(
        'icon_box_shape_color_top',
        [
            'label'     => esc_html__('Color Shape Top Vertical', 'ecofa'),
            'type'      => Controls_Manager::SLIDER,
            'size_units'=> ['px', 'em', '%'],
            'range' => [
                'px' => [
                    'min' => -30,
                    'max' => 60,
                ],
            ],
            'selectors' => [
                '{{WRAPPER}}.icon-shape-yes .elementor-icon i:after, {{WRAPPER}}.icon-shape-yes .elementor-icon svg:after' => 'top: {{SIZE}}{{UNIT}};',

            ],
            'condition' => [
                'icon_box_shape' => 'yes',
            ],
        ]
    );
}, 10, 2);


add_action('elementor/element/icon-box/section_style_icon/before_section_end', function ($element, $args) {
    $element->add_control(
        'icon_box_boxed_color_hover',
        [
            'label'     => esc_html__('Icon color when hovering to block', 'ecofa'),
            'type'      => Controls_Manager::COLOR,
            'default'   => '',
            'selectors' => [
                '{{WRAPPER}}:hover .elementor-icon i, {{WRAPPER}}:hover .elementor-icon svg' => 'fill: {{VALUE}}; color:{{VALUE}};',
            ]
        ]
    );
}, 10, 2);
    add_action('elementor/element/icon-box/section_style_icon/before_section_end', function ($element, $args) {
        $element->add_control(
            'effects_color',
            [
                'label'     => esc_html__('Effects color', 'ecofa'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}}.enable-effects-yes .elementor-icon-box-icon .elementor-icon' => 'background-color:{{VALUE}};',
                    '{{WRAPPER}}.enable-effects-style-yes .elementor-icon-box-icon .elementor-icon' => 'background-color:{{VALUE}};',
                ]
            ]
        );

        $element->add_control(
            'effects_color_hover',
            [
                'label'     => esc_html__('Effects color hover', 'ecofa'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}}.enable-effects-yes .elementor-icon-box-icon .elementor-icon:hover' => 'background-color:{{VALUE}};',
                    '{{WRAPPER}}.enable-effects-style-yes .elementor-icon-box-icon .elementor-icon:hover' => 'background-color:{{VALUE}};',
                ]
            ]
        );
        $element->add_responsive_control(
            'effects_width_svg',
            [
                'label'          => esc_html__('Width SVG', 'ecofa'),
                'type'           => Controls_Manager::SLIDER,
                'default'        => [
                    'unit' => '%',
                ],
                'tablet_default' => [
                    'unit' => '%',
                ],
                'mobile_default' => [
                    'unit' => '%',
                ],
                'size_units'     => ['%', 'px', 'vw'],
                'range'          => [
                    '%'  => [
                        'min' => 1,
                        'max' => 100,
                    ],
                    'px' => [
                        'min' => 1,
                        'max' => 1000,
                    ],
                    'vw' => [
                        'min' => 1,
                        'max' => 100,
                    ],
                ],
                'selectors'      => [
                    '{{WRAPPER}} .elementor-icon-box-icon .elementor-icon svg' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $element->add_responsive_control(
            'effects_height_svg',
            [
                'label'          => esc_html__('Height SVG', 'ecofa'),
                'type'           => Controls_Manager::SLIDER,
                'default'        => [
                    'unit' => '%',
                ],
                'tablet_default' => [
                    'unit' => '%',
                ],
                'mobile_default' => [
                    'unit' => '%',
                ],
                'size_units'     => ['%', 'px', 'vw'],
                'range'          => [
                    '%'  => [
                        'min' => 1,
                        'max' => 100,
                    ],
                    'px' => [
                        'min' => 1,
                        'max' => 1000,
                    ],
                    'vw' => [
                        'min' => 1,
                        'max' => 100,
                    ],
                ],
                'selectors'      => [
                    '{{WRAPPER}} .elementor-icon-box-icon .elementor-icon svg' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $element->add_responsive_control(
            'effects_width_icon',
            [
                'label'          => esc_html__('Width Effects', 'ecofa'),
                'type'           => Controls_Manager::SLIDER,
                'default'        => [
                    'unit' => '%',
                ],
                'tablet_default' => [
                    'unit' => '%',
                ],
                'mobile_default' => [
                    'unit' => '%',
                ],
                'size_units'     => ['%', 'px', 'vw'],
                'range'          => [
                    '%'  => [
                        'min' => 1,
                        'max' => 100,
                    ],
                    'px' => [
                        'min' => 1,
                        'max' => 1000,
                    ],
                    'vw' => [
                        'min' => 1,
                        'max' => 100,
                    ],
                ],
                'selectors'      => [
                    '{{WRAPPER}}.enable-effects-yes .elementor-icon-box-icon .elementor-icon' => 'width: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}}.enable-effects-style-yes .elementor-icon-box-icon .elementor-icon' => 'width: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $element->add_responsive_control(
            'effects_height_icon',
            [
                'label'          => esc_html__('Height Effects', 'ecofa'),
                'type'           => Controls_Manager::SLIDER,
                'default'        => [
                    'unit' => '%',
                ],
                'tablet_default' => [
                    'unit' => '%',
                ],
                'mobile_default' => [
                    'unit' => '%',
                ],
                'size_units'     => ['%', 'px', 'vw'],
                'range'          => [
                    '%'  => [
                        'min' => 1,
                        'max' => 100,
                    ],
                    'px' => [
                        'min' => 1,
                        'max' => 1000,
                    ],
                    'vw' => [
                        'min' => 1,
                        'max' => 100,
                    ],
                ],
                'selectors'      => [
                    '{{WRAPPER}}.enable-effects-yes .elementor-icon-box-icon .elementor-icon' => 'height: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}}.enable-effects-style-yes .elementor-icon-box-icon .elementor-icon' => 'height: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
}, 10, 2);

add_action('elementor/element/icon-box/section_style_icon/before_section_end', function ($element, $args) {
    $element->add_group_control(
        Group_Control_Border::get_type(),
        [
            'name'     => 'effect_border',
            'placeholder' => '1px',
            'default'     => '1px',
            'selector' => '{{WRAPPER}}.enable-effects-yes .elementor-icon-box-icon .elementor-icon',
            '{{WRAPPER}}.enable-effects-style-yes .elementor-icon-box-icon .elementor-icon',


        ]
    );
    $element->add_control(
        'border_color_hover',
        [
            'label'     => esc_html__('Border color hover', 'ecofa'),
            'type'      => Controls_Manager::COLOR,
            'default'   => '',
            'selectors' => [

                '{{WRAPPER}}.enable-effects-yes .elementor-icon-box-icon .elementor-icon:hover' => 'border-color:{{VALUE}};',
                '{{WRAPPER}}.enable-effects-style-yes .elementor-icon-box-icon .elementor-icon:hover' => 'border-color:{{VALUE}};',
            ]
        ]
    );
}, 10, 2);
    add_action('elementor/element/icon-box/section_style_icon/before_section_end', function ($element, $args) {
    $element->add_control(
        'icon_box_boxed_background_color_hover',
        [
            'label'     => esc_html__('Background color when hovering to block ', 'ecofa'),
            'type'      => Controls_Manager::COLOR,
            'default'   => '',
            'selectors' => [
                '{{WRAPPER}}:hover .elementor-icon' => 'background-color: {{VALUE}};',
            ],
            'conditions' => [
                'relation' => 'or',
                'terms' => [
                    [
                        'name' => 'view',
                        'operator' => '==',
                        'value' => 'stacked',
                    ],
                    [
                        'name' => 'view',
                        'operator' => '==',
                        'value' => 'framed',
                    ],
                ],
            ],
        ]
    );
}, 10, 2);

add_action('elementor/element/icon-box/section_icon/before_section_end', function ($element, $args) {
    $element->add_control(
        'circle_enable_effects',
        [
            'label'     => esc_html__('Effects', 'ecofa'),
            'type'      => Controls_Manager::SWITCHER,
            'prefix_class' => 'enable-effects-',
        ]
    );
    $element->add_control(
        'circle_enable_effects_style',
        [
            'label'     => esc_html__('Effects Style', 'ecofa'),
            'type'      => Controls_Manager::SWITCHER,
            'prefix_class' => 'enable-effects-style-',
        ]
    );
    $element->add_control(
        'number_efect',
        [
            'label'       => esc_html__('Number', 'ecofa'),
            'type'        => Controls_Manager::TEXT,
            'label_block' => true,
            'placeholder' => esc_html__('1', 'ecofa'),
            'condition'   => [
                'circle_enable_effects' => 'yes'
            ]
        ]
    );
}, 10, 2);



class Ecofa_Elementor_Icon_Box extends Widget_Icon_Box {

    /**
     * Render image box widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since 1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();

        $this->add_render_attribute( 'icon', 'class', [ 'elementor-icon', 'elementor-animation-' . $settings['hover_animation'] ] );

        $icon_tag = 'span';

        if ( ! isset( $settings['icon'] ) && ! Icons_Manager::is_migration_allowed() ) {
            // add old default
            $settings['icon'] = 'fa fa-star';
        }

        $has_icon = ! empty( $settings['icon'] );

        if ( ! empty( $settings['link']['url'] ) ) {
            $icon_tag = 'a';

            $this->add_link_attributes( 'link', $settings['link'] );
        }

        if ( $has_icon ) {
            $this->add_render_attribute( 'i', 'class', $settings['icon'] );
            $this->add_render_attribute( 'i', 'aria-hidden', 'true' );
        }

        $this->add_render_attribute( 'description_text', 'class', 'elementor-icon-box-description' );

        $this->add_inline_editing_attributes( 'title_text', 'none' );
        $this->add_inline_editing_attributes( 'description_text' );
        if ( ! $has_icon && ! empty( $settings['selected_icon']['value'] ) ) {
            $has_icon = true;
        }
        $migrated = isset( $settings['__fa4_migrated']['selected_icon'] );
        $is_new = ! isset( $settings['icon'] ) && Icons_Manager::is_migration_allowed();

        ?>
        <div class="elementor-icon-box-wrapper">
        <?php if ( $has_icon ) : ?>
            <div class="elementor-icon-box-icon">
            <<?php Utils::print_validated_html_tag( $icon_tag ); ?> <?php $this->print_render_attribute_string( 'icon' ); ?> <?php $this->print_render_attribute_string( 'link' ); ?>>
            <?php
            if ( $is_new || $migrated ) {
                Icons_Manager::render_icon( $settings['selected_icon'], [ 'aria-hidden' => 'true' ] );
            } elseif ( ! empty( $settings['icon'] ) ) {
                ?><i <?php $this->print_render_attribute_string( 'i' ); ?>></i><?php
            }
            ?>
            <?php if ($settings['number_efect']): ?>
                <span class="icon-box-number_efect"><?php echo esc_html($settings['number_efect']); ?></span>
            <?php endif; ?>
            </<?php Utils::print_validated_html_tag( $icon_tag ); ?>>

            </div>
        <?php endif; ?>
        <div class="elementor-icon-box-content">
        <<?php Utils::print_validated_html_tag( $settings['title_size'] ); ?> class="elementor-icon-box-title">
        <<?php Utils::print_validated_html_tag( $icon_tag ); ?> <?php $this->print_render_attribute_string( 'link' ); ?> <?php $this->print_render_attribute_string( 'title_text' ); ?>>
        <?php $this->print_unescaped_setting( 'title_text' ); ?>
        </<?php Utils::print_validated_html_tag( $icon_tag ); ?>>
        </<?php Utils::print_validated_html_tag( $settings['title_size'] ); ?>>
        <?php if ( ! Utils::is_empty( $settings['description_text'] ) ) : ?>
            <p <?php $this->print_render_attribute_string( 'description_text' ); ?>>
                <?php $this->print_unescaped_setting( 'description_text' ); ?>
            </p>
        <?php endif; ?>
        </div>

        </div>
        <?php
    }

    /**
     * Render icon box widget output in the editor.
     *
     * Written as a Backbone JavaScript template and used to generate the live preview.
     *
     * @since 2.9.0
     * @access protected
     */
    protected function content_template() {
        ?>
        <#
        var link = settings.link.url ? 'href="' + settings.link.url + '"' : '',
        iconTag = link ? 'a' : 'span',
        iconHTML = elementor.helpers.renderIcon( view, settings.selected_icon, { 'aria-hidden': true }, 'i' , 'object' ),
        migrated = elementor.helpers.isIconMigrated( settings, 'selected_icon' );

        view.addRenderAttribute( 'description_text', 'class', 'elementor-icon-box-description' );

        view.addInlineEditingAttributes( 'title_text', 'none' );
        view.addInlineEditingAttributes( 'description_text' );
        #>
        <div class="elementor-icon-box-wrapper">
            <?php // settings.icon is needed for older version ?>
            <# if ( settings.icon || settings.selected_icon.value ) { #>
            <div class="elementor-icon-box-icon">
                <{{{ iconTag + ' ' + link }}} class="elementor-icon elementor-animation-{{ settings.hover_animation }}">
                <# if ( iconHTML && iconHTML.rendered && ( ! settings.icon || migrated ) ) { #>
                {{{ iconHTML.value }}}
                <# } else { #>
                <i class="{{ settings.icon }}" aria-hidden="true"></i>
                <# } #>
            </{{{ iconTag }}}>
        </div>
        <# } #>
        <div class="elementor-icon-box-content">
            <# var titleSizeTag = elementor.helpers.validateHTMLTag( settings.title_size ); #>
            <{{{ titleSizeTag }}} class="elementor-icon-box-title">
            <{{{ iconTag + ' ' + link }}} {{{ view.getRenderAttributeString( 'title_text' ) }}}>{{{ settings.title_text }}}</{{{ iconTag }}}>
        </{{{ titleSizeTag }}}>
        <# if ( settings.description_text ) { #>
        <p {{{ view.getRenderAttributeString( 'description_text' ) }}}>{{{ settings.description_text }}}</p>
        <# } #>
        </div>
        </div>
        <?php
    }

}

$widgets_manager->register(new Ecofa_Elementor_Icon_Box());
