<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

if (!class_exists('Give')) {
    return;
}

use Ecofa\Elementor\Ecofa_Base_Widgets;
use Elementor\Controls_Manager;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;

class Ecofa_Elementor_Give_Campain extends Ecofa_Base_Widgets {

    public function get_name() {
        return 'ecofa-give-campain';
    }

    public function get_title() {
        return __('Ecofa Give Form Grid', 'ecofa');
    }

    public function get_categories() {
        return array('ecofa-addons');
    }

    public function get_script_depends() {
        return ['ecofa-elementor-give-form-grid'];
    }

    protected function register_controls() {
        $this->start_controls_section(
            'section_give_form',
            [
                'label' => __('Give Form Grid', 'ecofa'),
            ]
        );

        $this->add_control(
            'style',
            [
                'label'   => __('Style', 'ecofa'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'grid',
                'options' => [
                    'grid'    => esc_html__('Grid', 'ecofa'),
                    'grid-2'    => esc_html__('Grid 2', 'ecofa'),
                    'list'    => esc_html__('List', 'ecofa'),
                    'list-2'  => esc_html__('List 2', 'ecofa'),
                    'feature' => esc_html__('Feature', 'ecofa'),
                ],
            ]
        );

        $this->add_control(
            'form_id',
            [
                'label'       => __('Form ids', 'ecofa'),
                'type'        => Controls_Manager::SELECT2,
                'options'     => $this->get_form_ids(),
                'multiple'    => true,
                'description' => __('Enter a comma-separated list of form IDs. If empty, all published forms are displayed.', 'ecofa'),
            ]
        );

        $this->add_control(
            'excluded_form_id',
            [
                'label'       => __('Excluded Form IDs', 'ecofa'),
                'type'        => Controls_Manager::SELECT2,
                'options'     => $this->get_form_ids(),
                'multiple'    => true,
                'description' => __('Enter a comma-separated list of form IDs to exclude those from the grid.', 'ecofa'),
            ]
        );
        $enable_category = give_is_setting_enabled(give_get_option('categories', 'disabled'));
        if ($enable_category) {
            $this->add_control(
                'cats',
                [
                    'label'    => __('Category IDs', 'ecofa'),
                    'type'     => Controls_Manager::SELECT2,
                    'options'  => $this->get_form_taxonomy(),
                    'multiple' => true,
                ]
            );
        }

        $this->add_responsive_control(
            'column',
            [
                'label'              => __('Columns', 'ecofa'),
                'type'               => Controls_Manager::SELECT,
                'options'            => [
                    '1' => __('1', 'ecofa'),
                    '2' => __('2', 'ecofa'),
                    '3' => __('3', 'ecofa'),
                    '4' => __('4', 'ecofa'),
                ],
                'frontend_available' => true,
                'default'            => 4,
                'description'        => __('Sets the number of forms per row.', 'ecofa'),
            ]
        );

        $this->add_control(
            'column_spacing',
            [
                'label'              => esc_html__('Column Spacing', 'ecofa'),
                'type'               => Controls_Manager::SLIDER,
                'range'              => [
                    'px' => [
                        'max' => 100,
                    ],
                ],
                'default'            => [
                    'size' => 30,
                ],
                'condition'          => [
                    'enable_carousel!' => 'yes',
                ],
                'frontend_available' => true,
                'separator'          => 'after',
                'selectors'          => [

                    '{{WRAPPER}} .give-wrap .give-grid' => 'grid-gap: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'column_spacing_swiper',
            [
                'label'              => esc_html__('Column Spacing', 'ecofa'),
                'type'               => Controls_Manager::SLIDER,
                'range'              => [
                    'px' => [
                        'max' => 100,
                    ],
                ],
                'default'            => [
                    'size' => 30,
                ],
                'condition'          => [
                    'enable_carousel' => 'yes',
                ],
                'frontend_available' => true,
                'render_type'        => 'none',
                'separator'          => 'after',
            ]
        );

        $this->add_control(
            'show_goal',
            [
                'label'       => __('Show Goal', 'ecofa'),
                'type'        => Controls_Manager::SWITCHER,
                'label_on'    => 'Hide',
                'label_off'   => 'Show',
                'default'     => 'yes',
                'description' => __('Do you want to display the goal\'s progress bar?', 'ecofa'),
            ]
        );
        $this->add_control(
            'show_excerpt',
            [
                'label'     => __('Show Excerpt', 'ecofa'),
                'type'      => Controls_Manager::SWITCHER,
                'label_on'  => 'Hide',
                'label_off' => 'Show',
                'default'   => 'yes',
            ]
        );
        $this->add_control(
            'show_featured_image',
            [
                'label'     => __('Show Featured Image', 'ecofa'),
                'type'      => Controls_Manager::SWITCHER,
                'label_on'  => 'Hide',
                'label_off' => 'Show',
                'default'   => 'yes',
            ]
        );

        $this->add_control(
            'display_style',
            [
                'label'   => __('Display Style', 'ecofa'),
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    'redirect'     => __('Redirect', 'ecofa'),
                    'modal_reveal' => __('Modal', 'ecofa'),
                ],
                'default' => 'redirect'
            ]
        );

        $this->add_control(
            'forms_per_page',
            [
                'label'   => __('Forms Per Page', 'ecofa'),
                'type'    => Controls_Manager::NUMBER,
                'default' => 12,
            ]
        );

        $this->add_control(
            'show_paged',
            [
                'label'     => __('Enables/Disables pagination', 'ecofa'),
                'type'      => Controls_Manager::SWITCHER,
                'label_on'  => 'Hide',
                'label_off' => 'Show',
                'default'   => 'yes',
            ]
        );

        $this->add_control(
            'excerpt_length',
            [
                'label'   => __('Excerpt Length', 'ecofa'),
                'type'    => Controls_Manager::NUMBER,
                'default' => 25,
            ]
        );

        $this->add_responsive_control(
            'item_spacing',
            [
                'label'      => esc_html__('Spacing', 'ecofa'),
                'type'       => Controls_Manager::SLIDER,
                'range'      => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'size_units' => ['px', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .give-wrap .give-grid' => 'grid-gap: {{SIZE}}{{UNIT}}',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_style_wrap',
            [
                'label' => esc_html__('Wrap', 'ecofa'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'label'    => esc_html__('Box Shadow', 'ecofa'),
                'name'     => 'wrap_box_shadow',
                'selector' => '{{WRAPPER}} .give-wrap .give-card',
            ]
        );

        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'label'    => esc_html__('Box Shadow Hover', 'ecofa'),
                'name'     => 'wrap_box_shadow_hover',
                'selector' => '{{WRAPPER}} .give-wrap .give-card:hover',
            ]
        );

        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'      => 'wrap_border',
                'selector'  => '{{WRAPPER}} .give-wrap .give-card',
                'separator' => 'before',
            ]
        );

        $this->add_responsive_control(
            'wrap_border_radius',
            [
                'label'      => __('Border Radius', 'ecofa'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .give-wrap .give-card' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'wrapper_padding_inner',
            [
                'label'      => esc_html__('Padding', 'ecofa'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .give-wrap .give-card__body' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->get_control_carousel();

    }

    protected function render() {
        $settings = $this->get_settings_for_display();
        if ($settings['enable_carousel'] === 'yes') {
            $settings['show_paged']    = 'no';
            $settings['display_style'] = 'redirect';

        }
        $atts = [
            'columns'             => $settings['column'],
            'show_goal'           => $settings['show_goal'],
            'show_excerpt'        => $settings['show_excerpt'],
            'show_featured_image' => $settings['show_featured_image'],
            'display_style'       => $settings['display_style'],
            'forms_per_page'      => $settings['forms_per_page'],
            'paged'               => $settings['show_paged'],
            'excerpt_length'      => $settings['excerpt_length'],
            'image_size'          => 'ecofa-featured-image-large'
        ];
        if ($settings['column'] <= 2) {
            $atts['image_size'] = 'full';
        }
        if (!empty($settings['form_id'])) {
            $atts['ids'] = implode(',', $settings['form_id']);
        }
        if (!empty($settings['form_id'])) {
            $atts['exclude'] = implode(',', $settings['excluded_form_id']);
        }
        if (!empty($settings['cats'])) {
            $atts['cats'] = implode(',', $settings['cats']);
        }
        if (!empty($settings['style'])) {
            $atts['style'] = 'shortcode-form-' . $settings['style'];
        }
        $code = '';
        foreach ($atts as $key => $value) {
            $code .= $key . '="' . (empty($value) ? 'false' : $value) . '" ';
        }

        if ($settings['enable_carousel'] === 'yes') {
            $this->add_render_attribute('wrap', 'class', 'ecofa-wrapper ecofa-swiper-wrapper swiper');
            echo '<div ' . $this->get_render_attribute_string('wrap') . '>';
            printf('%s', $this->get_swiper_navigation_for_product());
        }

        echo do_shortcode('[ecofa_give_form_grid ' . $code . ' ]');

        if ($settings['enable_carousel'] === 'yes') {
            echo '</div>';
        }
    }

    private function get_form_ids() {
        $args          = array(
            'post_type'      => 'give_forms',
            'posts_per_page' => -1,
            'post_status'    => 'publish',
        );
        $give_form_ids = array();
        $give_forms    = get_posts($args);
        foreach ($give_forms as $give_form) {
            $form_title                    = empty($give_form->post_title) ? sprintf(__('Untitled (#%s)', 'ecofa'), $give_form->ID) : $give_form->post_title;
            $give_form_ids[$give_form->ID] = $form_title;
        }
        return $give_form_ids;
    }

    private function get_form_taxonomy() {
        $enable_category = give_is_setting_enabled(give_get_option('categories', 'disabled'));
        if ($enable_category) {
            $args               = array(
                'hide_empty' => false,
                'orderby'    => 'name',
                'order'      => 'ASC',
                'number'     => 0,
            );
            $terms              = get_terms('give_forms_category', $args);
            $give_form_taxonomy = array();
            foreach ($terms as $term) {
                $give_form_taxonomy[$term->term_id] = $term->name;
            }
            return $give_form_taxonomy;
        }
    }
}

$widgets_manager->register(new Ecofa_Elementor_Give_Campain());