<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Image_Size;
use Elementor\Repeater;
use Ecofa\Elementor\Ecofa_Base_Widgets;

class Ecofa_Elementor_History_Carousel extends Ecofa_Base_Widgets {

    /**
     * Get widget name.
     *
     * Retrieve testimonial widget name.
     *
     * @return string Widget name.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_name() {
        return 'ecofa-history-carousel';
    }

    /**
     * Get widget title.
     *
     * Retrieve testimonial widget title.
     *
     * @return string Widget title.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_title() {
        return esc_html__('Ecofa History Carousel', 'ecofa');
    }

    /**
     * Get widget icon.
     *
     * Retrieve testimonial widget icon.
     *
     * @return string Widget icon.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_icon() {
        return 'eicon-gallery-grid';
    }

    public function get_script_depends() {
        return ['ecofa-elementor-history-carousel'];
    }

    public function get_categories() {
        return array('ecofa-addons');
    }

    /**
     * Register testimonial widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(
            'section_history',
            [
                'label' => esc_html__('History', 'ecofa'),
            ]
        );

        $repeater = new Repeater();

        $repeater->add_control(
            'years',
            [
                'label'       => esc_html__('Years', 'ecofa'),
                'type'        => Controls_Manager::TEXT,
                'default'     => '1990',
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'image_title',
            [
                'label'       => esc_html__('Title', 'ecofa'),
                'type'        => Controls_Manager::TEXT,
                'default'     => 'title',
                'label_block' => true,
            ]
        );
        $repeater->add_control(
            'history_content',
            [
                'label'       => esc_html__('Content', 'ecofa'),
                'type'        => Controls_Manager::TEXTAREA,
                'default'     => 'Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.',
                'label_block' => true,
                'rows'        => '10',
            ]
        );

        $repeater->add_control(
            'image_link_source',
            [
                'label'      => esc_html__('Choose Image', 'ecofa'),
                'default'    => [
                    'url' => Elementor\Utils::get_placeholder_image_src(),
                ],
                'type'       => Controls_Manager::MEDIA,
                'show_label' => false,
            ]
        );

        $repeater->add_control(
            'image_link',
            [
                'label'       => esc_html__('Link to', 'ecofa'),
                'placeholder' => esc_html__('https://your-link.com', 'ecofa'),
                'type'        => Controls_Manager::URL,
                'default'     => [
                    'url' => '#',
                ],
            ]
        );

        $repeater->add_control(
            'target_link',
            [
                'label'   => esc_html__('Target', 'ecofa'),
                'default' => 'yes',
                'type'    => Controls_Manager::SWITCHER,
            ]
        );

        $this->add_control(
            'image-carousel',
            [
                'label'       => esc_html__('Items', 'ecofa'),
                'type'        => Controls_Manager::REPEATER,
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{{ image_title }}}',
            ]
        );

        $this->add_group_control(
            Elementor\Group_Control_Image_Size::get_type(),
            [
                'name'      => 'image', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `brand_image_size` and `brand_image_custom_dimension`.
                'default'   => 'full',
                'separator' => 'none',
            ]
        );


        $this->add_control(
            'view',
            [
                'label'   => esc_html__('View', 'ecofa'),
                'type'    => Controls_Manager::HIDDEN,
                'default' => 'traditional',
            ]
        );
        $this->add_responsive_control(
            'height-history',
            [
                'label'              => __( 'Height', 'ecofa' ),
                'type'               => Controls_Manager::SLIDER,
                'default'            => [
                    'unit' => '%',
                ],
                'tablet_default'     => [
                    'unit' => '%',
                ],
                'mobile_default'     => [
                    'unit' => '%',
                ],
                'size_units'         => ['px', 'vw' ],
                'range'              => [

                    'px' => [
                        'min' => 1,
                        'max' => 1000,
                    ],
                    'vw' => [
                        'min' => 1,
                        'max' => 100,
                    ],
                ],
                'selectors'          => [
                    '{{WRAPPER}} .ecofa-history-swiper' => 'height: {{SIZE}}{{UNIT}};',
                ],

            ]
        );
        $this->add_responsive_control(
            'align',
            [
                'label' => esc_html__( 'Alignment', 'ecofa' ),
                'type' => Controls_Manager::CHOOSE,
                'options' => [
                    'left' => [
                        'title' => esc_html__( 'Left', 'ecofa' ),
                        'icon' => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__( 'Center', 'ecofa' ),
                        'icon' => 'eicon-text-align-center',
                    ],
                    'right' => [
                        'title' => esc_html__( 'Right', 'ecofa' ),
                        'icon' => 'eicon-text-align-right',
                    ],
                    'justify' => [
                        'title' => esc_html__( 'Justified', 'ecofa' ),
                        'icon' => 'eicon-text-align-justify',
                    ],
                ],
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}}' => 'text-align: {{VALUE}};',
                ],
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'image_style',
            [
                'label' => esc_html__('Image', 'ecofa'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_responsive_control(
            'width-image',
            [
                'label'              => __( 'Width Image', 'ecofa' ),
                'type'               => Controls_Manager::SLIDER,
                'default'            => [
                    'unit' => '%',
                ],
                'tablet_default'     => [
                    'unit' => '%',
                ],
                'mobile_default'     => [
                    'unit' => '%',
                ],
                'size_units'         => [ '%', 'px', 'vw' ],
                'range'              => [
                    '%'  => [
                        'min' => 1,
                        'max' => 100,
                    ],
                    'px' => [
                        'min' => 1,
                        'max' => 1000,
                    ],
                    'vw' => [
                        'min' => 1,
                        'max' => 100,
                    ],
                ],
                'selectors'          => [
                    '{{WRAPPER}} img' => 'width: {{SIZE}}{{UNIT}};',
                ],

            ]
        );
        $this->add_responsive_control(
            'image_spacing',
            [
                'label' => esc_html__( 'Spacing', 'ecofa' ),
                'type' => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} img' => 'margin-bottom: {{SIZE}}{{UNIT}}',
                ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                    'em' => [
                        'min' => 0.1,
                        'max' => 20,
                    ],
                    'vh' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'size_units' => [ 'px', 'em', 'rem', 'vh', 'custom' ],
            ]
        );
        $this->end_controls_section();


        $this->start_controls_section(
            'history_style',
            [
                'label' => esc_html__('Title', 'ecofa'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'tilte_typography',
                'selector' => '{{WRAPPER}} .title',
            ]
        );

        $this->add_control(
            'title_color',
            [
                'label'     => esc_html__('Color', 'ecofa'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .title, {{WRAPPER}} .title span' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'title_color_hover',
            [
                'label'     => esc_html__('Text Color Hover', 'ecofa'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .title:hover, {{WRAPPER}} .title span:hover' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'title_spacing',
            [
                'label' => esc_html__( 'Spacing', 'ecofa' ),
                'type' => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .title, {{WRAPPER}} .title span' => 'margin-bottom: {{SIZE}}{{UNIT}}',
                ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                    'em' => [
                        'min' => 0.1,
                        'max' => 20,
                    ],
                    'vh' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'size_units' => [ 'px', 'em', 'rem', 'vh', 'custom' ],
            ]
        );
       $this->end_controls_section();

        $this->start_controls_section(
            'history_years_style',
            [
                'label' => esc_html__('Years', 'ecofa'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'years_typography',
                'selector' => '{{WRAPPER}} .years',
            ]
        );

        $this->add_control(
            'years_color',
            [
                'label'     => esc_html__('Color', 'ecofa'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .years, {{WRAPPER}} .years span' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'years_color_hover',
            [
                'label'     => esc_html__('Text Color Hover', 'ecofa'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .years:hover, {{WRAPPER}} .years span:hover' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'years_spacing',
            [
                'label' => esc_html__( 'Spacing', 'ecofa' ),
                'type' => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .years, {{WRAPPER}} .years span' => 'margin-bottom: {{SIZE}}{{UNIT}}',
                ],
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                    'em' => [
                        'min' => 0.1,
                        'max' => 20,
                    ],
                    'vh' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'size_units' => [ 'px', 'em', 'rem', 'vh', 'custom' ],
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'history_content_style',
            [
                'label' => esc_html__('Content', 'ecofa'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'content_typography',
                'selector' => '{{WRAPPER}} .history-content',
            ]
        );

        $this->add_control(
            'content_color',
            [
                'label'     => esc_html__('Color', 'ecofa'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .history-content, {{WRAPPER}} .history-content span' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'content_color_hover',
            [
                'label'     => esc_html__('Text Color Hover', 'ecofa'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .history-content:hover, {{WRAPPER}} .history-content span:hover' => 'color: {{VALUE}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'width-content',
            [
                'label'              => __( 'Width', 'ecofa' ),
                'type'               => Controls_Manager::SLIDER,
                'default'            => [
                    'unit' => '%',
                ],
                'tablet_default'     => [
                    'unit' => '%',
                ],
                'mobile_default'     => [
                    'unit' => '%',
                ],
                'size_units'         => [ '%', 'px', 'vw' ],
                'range'              => [
                    '%'  => [
                        'min' => 1,
                        'max' => 100,
                    ],
                    'px' => [
                        'min' => 1,
                        'max' => 1000,
                    ],
                    'vw' => [
                        'min' => 1,
                        'max' => 100,
                    ],
                ],
                'selectors'          => [
                    '{{WRAPPER}} .history-content, {{WRAPPER}} .history-content span' => 'width: {{SIZE}}{{UNIT}};',
                ],

            ]
        );

        $this->end_controls_section();
    }

    /**
     * Render testimonial widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */

    protected function render() {
        $settings = $this->get_settings_for_display();
        if (!empty($settings['image-carousel']) && is_array($settings['image-carousel'])) {
            $this->add_render_attribute('wrapper', 'class', 'elementor-image-carousel-item-wrapper');

//            $this->get_data_elementor_columns();

            $this->add_render_attribute('wrapper', 'class', 'ecofa-swiper-history-wrapper swiper-1');
            $this->add_render_attribute('container', 'class', ['swiper', 'ecofa-history-swiper']);
            $this->add_render_attribute('inner', 'class', 'swiper-wrapper');
            $this->add_render_attribute('item', 'class', 'swiper-slide');
            ?>
            <div <?php $this->print_render_attribute_string('wrapper'); ?>>
                <div <?php $this->print_render_attribute_string('container'); ?>>
                    <div <?php $this->print_render_attribute_string('inner'); ?>>
                        <?php foreach ($settings['image-carousel'] as $index => $item):
                            $repeater_image_link_key = $this->get_repeater_setting_key('image_link', 'image-carousel', $index);

                            $this->add_render_attribute($repeater_image_link_key, 'href', $item['image_link']['url']);

                            if ($item['target_link']) {
                                $this->add_render_attribute($repeater_image_link_key, 'target', '_blank');
                            }
                            ?>
                            <div <?php $this->print_render_attribute_string('item'); ?>>
                                <a <?php $this->print_render_attribute_string($repeater_image_link_key); ?>>
                                    <div class="col-left">
                                        <?php
                                        $image_url = Group_Control_Image_Size::get_attachment_image_src($item['image_link_source']['id'], 'image', $settings);
                                        if (!$image_url && isset($attachment['url'])) {
                                            $image_url = $item['url'];
                                        } ?>
                                        <img class="image" src="<?php echo esc_url($image_url); ?>" alt="image">
                                    </div>
                                    <div class="col-right">
                                        <?php if ($item['years']) : ?>
                                            <span class="years"><?php printf('%s', $item['years']); ?></span>
                                        <?php endif; ?>
                                        <?php if ($item['image_title']) : ?>
                                            <span class="title"><?php printf('%s', $item['image_title']); ?></span>
                                        <?php endif; ?>
                                        <?php if ($item['history_content']) : ?>
                                            <span class="history-content"><?php printf('%s', $item['history_content']); ?></span>
                                        <?php endif; ?>
                                    </div>
                                </a>
                            </div>
                        <?php endforeach; ?>
                    </div>
                </div>
                <div class="swiper-scrollbar"></div>
            </div>
            <?php
        }
    }

}

$widgets_manager->register(new Ecofa_Elementor_History_Carousel());