<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

use Ecofa\Elementor\Ecofa_Base_Widgets;
use Elementor\Controls_Manager;
use Elementor\Core\Kits\Documents\Tabs\Global_Colors;
use Elementor\Core\Kits\Documents\Tabs\Global_Typography;
use Elementor\Group_Control_Background;
use Elementor\Group_Control_Typography;


/**
 * Class Ecofa_Elementor_Blog
 */
class Ecofa_Elementor_Post_Grid extends Ecofa_Base_Widgets {

    public function get_name() {
        return 'ecofa-post-grid';
    }

    public function get_title() {
        return esc_html__('Posts Grid', 'ecofa');
    }

    /**
     * Get widget icon.
     *
     * Retrieve testimonial widget icon.
     *
     * @return string Widget icon.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_icon() {
        return 'eicon-posts-grid';
    }

    public function get_categories() {
        return array('ecofa-addons');
    }

    public function get_script_depends() {
        return ['ecofa-elementor-posts-grid'];
    }

    protected function register_controls() {
        $this->start_controls_section(
            'section_query',
            [
                'label' => esc_html__('Query', 'ecofa'),
                'tab'   => Controls_Manager::TAB_CONTENT,
            ]
        );

        $this->add_control(
            'posts_per_page',
            [
                'label'   => esc_html__('Posts Per Page', 'ecofa'),
                'type'    => Controls_Manager::NUMBER,
                'default' => 6,
            ]
        );


        $this->add_control(
            'advanced',
            [
                'label' => esc_html__('Advanced', 'ecofa'),
                'type'  => Controls_Manager::HEADING,
            ]
        );

        $this->add_control(
            'orderby',
            [
                'label'   => esc_html__('Order By', 'ecofa'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'post_date',
                'options' => [
                    'post_date'  => esc_html__('Date', 'ecofa'),
                    'post_title' => esc_html__('Title', 'ecofa'),
                    'menu_order' => esc_html__('Menu Order', 'ecofa'),
                    'rand'       => esc_html__('Random', 'ecofa'),
                ],
            ]
        );

        $this->add_control(
            'order',
            [
                'label'   => esc_html__('Order', 'ecofa'),
                'type'    => Controls_Manager::SELECT,
                'default' => 'desc',
                'options' => [
                    'asc'  => esc_html__('ASC', 'ecofa'),
                    'desc' => esc_html__('DESC', 'ecofa'),
                ],
            ]
        );

        $this->add_control(
            'categories',
            [
                'label'       => esc_html__('Categories', 'ecofa'),
                'type'        => Controls_Manager::SELECT2,
                'options'     => $this->get_post_categories(),
                'label_block' => true,
                'multiple'    => true,
            ]
        );

        $this->add_control(
            'cat_operator',
            [
                'label'     => esc_html__('Category Operator', 'ecofa'),
                'type'      => Controls_Manager::SELECT,
                'default'   => 'IN',
                'options'   => [
                    'AND'    => esc_html__('AND', 'ecofa'),
                    'IN'     => esc_html__('IN', 'ecofa'),
                    'NOT IN' => esc_html__('NOT IN', 'ecofa'),
                ],
                'condition' => [
                    'categories!' => ''
                ],
            ]
        );

        $this->add_control(
            'layout',
            [
                'label' => esc_html__('Layout', 'ecofa'),
                'type'  => Controls_Manager::HEADING,
            ]
        );

        $this->add_control(
            'post_style',
            [
                'label'   => esc_html__('Style', 'ecofa'),
                'type'    => \Elementor\Controls_Manager::SELECT,
                'options' => [
                    'post-special' => esc_html__('Special', 'ecofa'),
                    'post-style-1' => esc_html__('Style 1', 'ecofa'),
                    'post-style-2' => esc_html__('Style 2', 'ecofa'),
                    'post-style-3' => esc_html__('Style 3', 'ecofa'),
                    'post-style-4' => esc_html__('Style 4', 'ecofa'),
                    'post-style-5' => esc_html__('Style 5', 'ecofa'),
                    'post-style-6' => esc_html__('Style 6', 'ecofa'),
                ],
                'default' => 'post-special'
            ]
        );
        $this->add_responsive_control(
            'height-post',
            [
                'label'              => __( 'Height', 'ecofa' ),
                'type'               => Controls_Manager::SLIDER,
                'default'            => [
                    'unit' => '%',
                ],
                'tablet_default'     => [
                    'unit' => '%',
                ],
                'mobile_default'     => [
                    'unit' => '%',
                ],
                'size_units'         => ['px', 'vw' ],
                'range'              => [

                    'px' => [
                        'min' => 1,
                        'max' => 1000,
                    ],
                    'vw' => [
                        'min' => 1,
                        'max' => 1000,
                    ],
                ],
                'selectors'          => [
                    '{{WRAPPER}} .post-inner .post-thumbnail .entry-thumbnail' => 'padding-top: {{SIZE}}{{UNIT}};',
                ],

            ]
        );
        $this->end_controls_section();

        $this->get_control_pagination();
        $this->get_controls_column();
        $this->get_control_carousel();
    }

    protected function get_post_categories() {
        $categories = get_terms(array(
                'taxonomy'   => 'category',
                'hide_empty' => false,
            )
        );
        $results    = array();
        if (!is_wp_error($categories)) {
            foreach ($categories as $category) {
                $results[$category->slug] = $category->name;
            }
        }
        return $results;
    }

    public static function get_query_args($settings) {
        $query_args = [
            'post_type'           => 'post',
            'orderby'             => $settings['orderby'],
            'order'               => $settings['order'],
            'ignore_sticky_posts' => 1,
            'post_status'         => 'publish', // Hide drafts/private posts for admins
        ];

        if (!empty($settings['categories'])) {
            $categories = array();
            foreach ($settings['categories'] as $category) {
                $cat = get_term_by('slug', $category, 'category');
                if (!is_wp_error($cat) && is_object($cat)) {
                    $categories[] = $cat->term_id;
                }
            }

            if ($settings['cat_operator'] == 'AND') {
                $query_args['category__and'] = $categories;
            } elseif ($settings['cat_operator'] == 'IN') {
                $query_args['category__in'] = $categories;
            } else {
                $query_args['category__not_in'] = $categories;
            }
        }

        $query_args['posts_per_page'] = $settings['posts_per_page'];

        if (is_front_page()) {
            $query_args['paged'] = (get_query_var('page')) ? get_query_var('page') : 1;
        } else {
            $query_args['paged'] = (get_query_var('paged')) ? get_query_var('paged') : 1;
        }

        return $query_args;
    }

    public function query_posts() {
        $query_args = $this->get_query_args($this->get_settings());
        return new WP_Query($query_args);
    }


    protected function render() {
        $settings = $this->get_settings_for_display();

        $query = $this->query_posts();

        if (!$query->found_posts) {
            return;
        }
        $this->add_render_attribute('wrapper', 'class', ['elementor-post-wrapper', 'layout-' . $settings['post_style']]);
        // Item
        $this->add_render_attribute('item', 'class', 'elementor-posts-item');
        $this->get_data_elementor_columns();

        ?>
        <div <?php $this->print_render_attribute_string('wrapper'); ?>>
            <div <?php $this->print_render_attribute_string('container'); ?>>
                <div <?php $this->print_render_attribute_string('inner'); ?>>
                    <?php
                    $style = $settings['post_style'];
                    $count = 0;
                    while ($query->have_posts()) {
                        if ($count == 5) {
                            $count = 0;
                        }
                        $count++;
                        $query->the_post(); ?>
                        <div <?php $this->print_render_attribute_string('item'); ?>>
                            <?php if ($style == 'post-special'): ?>
                                <?php if ($count == 2): ?>
                                    <?php get_template_part('template-parts/posts-grid/item-post-style-5'); ?>
                                <?php else: ?>
                                    <?php get_template_part('template-parts/posts-grid/item-post-style-4'); ?>
                                <?php endif ?>
                            <?php else: ?>
                                <?php get_template_part('template-parts/posts-grid/item-' . $style); ?>
                            <?php endif ?>

                        </div>
                        <?php
                    }
                    ?>
                </div>
            </div>
            <?php $this->render_loop_footer(); ?>
            <?php $this->get_swiper_navigation($query->post_count); ?>
        </div>
        <?php
        wp_reset_postdata();
    }
}

$widgets_manager->register(new Ecofa_Elementor_Post_Grid());