<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Image_Size;
use Elementor\Icons_Manager;use Elementor\Repeater;
use Ecofa\Elementor\Ecofa_Base_Widgets;use Elementor\Widget_Base;


class Ecofa_Elementor_Protect extends Ecofa_Base_Widgets {

    /**
     * Get widget name.
     *
     * Retrieve testimonial widget name.
     *
     * @return string Widget name.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_name() {
        return 'ecofa-protect';
    }

    /**
     * Get widget title.
     *
     * Retrieve testimonial widget title.
     *
     * @return string Widget title.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_title() {
        return esc_html__('Ecofa Protect', 'ecofa');
    }

    /**
     * Get widget icon.
     *
     * Retrieve testimonial widget icon.
     *
     * @return string Widget icon.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_icon() {
        return 'eicon-banner';
    }

    public function get_script_depends() {
        return ['ecofa-elementor-protect'];
    }

    public function get_categories() {
        return array('ecofa-addons');
    }

    /**
     * Register testimonial widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls($args = []) {
        $this->start_controls_section(
            'section_protect',
            [
                'label' => esc_html__('Protect', 'ecofa'),
            ]
        );
        $default_args = [
            'section_condition' => [],
            'button_default_text' => esc_html__( 'Click here', 'ecofa' ),
            'text_control_label' => esc_html__( 'Text', 'ecofa' ),
            'alignment_control_prefix_class' => 'elementor%s-align-',
            'alignment_default' => '',
            'icon_exclude_inline_options' => [],
        ];
        $args = wp_parse_args( $args, $default_args );
        $repeater = new Repeater();
        $repeater->add_control(
            'protect_image',
            [
                'label'      => esc_html__('Choose Image', 'ecofa'),
                'type'       => Controls_Manager::MEDIA,
                'show_label' => false,
            ]
        );
        $repeater->add_control(
            'protect_title',
            [
                'label'   => esc_html__('Title', 'ecofa'),
                'type'    => Controls_Manager::TEXT,
                'default' => 'protect title',
            ]
        );
        $repeater->add_control(
            'protect_sub_title',
            [
                'label'       => esc_html__('Sub title', 'ecofa'),
                'type'        => Controls_Manager::TEXTAREA,
                'default'     => 'Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.',
                'label_block' => true,
                'rows'        => '10',
            ]
        );
        $this->add_control(
            'protect',
            [
                'label'       => esc_html__('Items', 'ecofa'),
                'type'        => Controls_Manager::REPEATER,
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{{ protect_title }}}',
            ]
        );
        $this->add_group_control(
            Group_Control_Image_Size::get_type(),
            [
                'name' => 'protect_image', // Usage: `{name}_size` and `{name}_custom_dimension`, in this case `testimonial_image_size` and `testimonial_image_custom_dimension`.
                'default' => 'full',
                'separator' => 'none',
            ]
        );
        $this->add_control(
            'button',
            [
                'label'     => esc_html__('Button Text', 'ecofa'),
                'type'      => Controls_Manager::TEXT,
                'dynamic'   => [
                    'active' => true,
                ],
                'default'   => esc_html__('Click Here', 'ecofa'),
                'separator' => 'before',
            ]
        );
        $this->add_control(
            'selected_icon',
            [
                'label' => esc_html__( 'Icon', 'ecofa' ),
                'type' => Controls_Manager::ICONS,
                'fa4compatibility' => 'icon',
                'skin' => 'inline',
                'label_block' => false,
                'condition' => $args['section_condition'],
                'icon_exclude_inline_options' => $args['icon_exclude_inline_options'],
            ]
        );
        $this->add_control(
            'icon_align',
            [
                'label' => esc_html__( 'Icon Position', 'ecofa' ),
                'type' => Controls_Manager::SELECT,
                'default' => 'left',
                'options' => [
                    'left' => esc_html__( 'Before', 'ecofa' ),
                    'right' => esc_html__( 'After', 'ecofa' ),
                ],
                'condition' => array_merge( $args['section_condition'], [ 'selected_icon[value]!' => '' ] ),
            ]
        );
        $this->add_responsive_control(
            'button_icon_spacing',
            [
                'label'     => esc_html__('Spacing', 'ecofa'),
                'type'      => Controls_Manager::SLIDER,
                'selectors' => [
                    '{{WRAPPER}} .elementor-button .button-icon.elementor-align-icon-left'  => 'margin-right: {{SIZE}}{{UNIT}};',
                    '{{WRAPPER}} .elementor-button .button-icon.elementor-align-icon-right' => 'margin-left: {{SIZE}}{{UNIT}};',

                ],
                'condition' => [
                    'button_icon[value]!' => '',
                    'show_button_link!'   => 'yes',
                ],
            ]
        );
        $this->add_control(
            'link',
            [
                'label'       => esc_html__('Link', 'ecofa'),
                'type'        => Controls_Manager::URL,
                'dynamic'     => [
                    'active' => true,
                ],
                'default'     => [
                    'url' => '#',
                ],
                'placeholder' => esc_html__('https://your-link.com', 'ecofa'),

            ]
        );
        $this->add_control(
            'link_click',
            [
                'label'     => esc_html__('Apply Link On', 'ecofa'),
                'type'      => Controls_Manager::SELECT,
                'options'   => [
                    'box'    => esc_html__('Whole Box', 'ecofa'),
                    'protect_button' => esc_html__('Button Only', 'ecofa'),
                ],
                'default'   => 'protect_button',
                'separator' => 'none',
                'condition' => [
                    'link[url]!' => '',
                ],
            ]
        );
        $this->end_controls_section();
        $this->start_controls_section(
            'section_style_protect_wrapper',
            [
                'label' => esc_html__('Wrapper', 'ecofa'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_responsive_control(
            'padding_protect_wrapper',
            [
                'label'      => esc_html__('Padding', 'ecofa'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}}' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'margin_protect_wrapper',
            [
                'label'      => esc_html__('Margin', 'ecofa'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors'  => [
                    '{{WRAPPER}}' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->end_controls_section();
        $this->start_controls_section(
            'section_style_protect_image',
            [
                'label' => esc_html__('Image', 'ecofa'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );


        $this->add_control(
            'image_border_radius',
            [
                'label' => esc_html__('Border Radius', 'ecofa'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors' => [
                    '{{WRAPPER}} .elementor-protect-item .pro-image img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'image_padding',
            [
                'label' => esc_html__('Padding', 'ecofa'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .elementor-protect-item .pro-image' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'image_margin',
            [
                'label' => esc_html__('Margin', 'ecofa'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .elementor-protect-item .pro-image' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->end_controls_section();
        $this->start_controls_section(
            'section_style_protect_title',
            [
                'label' => esc_html__('Title', 'ecofa'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'protect_title_color',
            [
                'label' => esc_html__('Color', 'ecofa'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-protect-item .pro-content .pro-title' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'protect_title_color_hover',
            [
                'label' => esc_html__('Hover Color', 'ecofa'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-protect-item .pro-content .pro-title:hover' => 'color: {{VALUE}} !important;',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'protect_title_typography',
                'selector' => '{{WRAPPER}} .elementor-protect-item .pro-content .pro-title',
            ]
        );

        $this->add_responsive_control(
            'protect_title_space',
            [
                'label' => esc_html__('Spacing', 'ecofa'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-protect-item .pro-content .pro-title' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'padding_protect_content',
            [
                'label'      => esc_html__('Padding', 'ecofa'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .elementor-protect-item .pro-content' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->end_controls_section();

        $this->start_controls_section(
            'section_style_protect_sub_title',
            [
                'label' => esc_html__('Sub Title', 'ecofa'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'protect_sub_title_color',
            [
                'label' => esc_html__('Color', 'ecofa'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-protect-item .pro-content .pro-subtitle' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'protect_sub_title_color_hover',
            [
                'label' => esc_html__('Hover Color', 'ecofa'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-protect-item .pro-content .pro-subtitle:hover' => 'color: {{VALUE}} !important;',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name' => 'name_typography',
                'selector' => '{{WRAPPER}} .elementor-protect-item .pro-content .pro-subtitle',
            ]
        );

        $this->add_responsive_control(
            'protect_sub_title_space',
            [
                'label' => esc_html__('Spacing', 'ecofa'),
                'type' => Controls_Manager::SLIDER,
                'range' => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-protect-item .pro-content .pro-subtitle' => 'margin-bottom: {{SIZE}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'protect_button_section_style',
            [
                'label' => esc_html__('Button', 'ecofa'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'button_style_theme',
            [
                'label'        => esc_html__('Style', 'ecofa'),
                'type'         => Controls_Manager::SELECT,
                'options'      => [
                    'default' => 'Default',
                    'outline' => 'Outline',
                    'link'    => 'Link',
                ],
                'default'      => 'default',
                'prefix_class' => 'button-protect-style-ecofa-',
            ]
        );
        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'      => 'button_typography',
                'selector'  => '{{WRAPPER}} .elementor-protect-item  .pro-content  .pro-button .pro-button-wapper .elementor-button .elementor-button-text',
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'        => 'button_border_width',
                'placeholder' => '1px',
                'default'     => '1px',
                'selector'    => '{{WRAPPER}} .elementor-protect-item  .pro-content  .pro-button .pro-button-wapper .elementor-button',
                'separator'   => 'before',
            ]
        );
        $this->add_control(
            'button_border_radius',
            [
                'label'     => esc_html__('Border Radius', 'ecofa'),
                'type'      => Controls_Manager::SLIDER,
                'range'     => [
                    'px' => [
                        'min' => 0,
                        'max' => 100,
                    ],
                ],
                'selectors' => [
                    '{{WRAPPER}} .elementor-protect-item  .pro-content  .pro-button .pro-button-wapper .elementor-button' => 'border-radius: {{SIZE}}{{UNIT}};',
                ],
            ]
        );
        $this->start_controls_tabs('button_tabs');

        $this->start_controls_tab('button_normal',
            [
                'label' => esc_html__('Normal', 'ecofa'),
            ]
        );

        $this->add_control(
            'button_text_color',
            [
                'label'     => esc_html__('Text Color', 'ecofa'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-protect-item  .pro-content  .pro-button .pro-button-wapper .elementor-button .elementor-button-text' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'button_background_color',
            [
                'label'     => esc_html__('Background Color', 'ecofa'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-protect-item  .pro-content  .pro-button .pro-button-wapper .elementor-button' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'button_border_color',
            [
                'label'     => esc_html__('Border Color', 'ecofa'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-protect-item  .pro-content  .pro-button .pro-button-wapper .elementor-button' => 'border-color: {{VALUE}};',
                ],
            ]
        );
        $this->add_control(
            'button_icon_color',
            [
                'label'     => esc_html__('Icon Color', 'ecofa'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-protect-item  .pro-content  .pro-button .pro-button-wapper .elementor-button .elementor-button-icon i'                                        => 'fill: {{VALUE}}; color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_tab();

        $this->start_controls_tab(
            'button-hover',
            [
                'label' => esc_html__('Hover', 'ecofa'),
            ]
        );

        $this->add_control(
            'button_hover_text_color',
            [
                'label'     => esc_html__('Text Color', 'ecofa'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-protect-item  .pro-content  .pro-button .pro-button-wapper .elementor-button:hover .elementor-button-text' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'button_hover_background_color',
            [
                'label'     => esc_html__('Background Color', 'ecofa'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-protect-item  .pro-content  .pro-button .pro-button-wapper .elementor-button:hover' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'button_hover_border_color',
            [
                'label'     => esc_html__('Border Color', 'ecofa'),
                'type'      => Controls_Manager::COLOR,
                'selectors' => [
                    '{{WRAPPER}} .elementor-protect-item  .pro-content  .pro-button .pro-button-wapper .elementor-button:hover' => 'border-color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'button_hover_icon_color',
            [
                'label'     => esc_html__('Icon Color', 'ecofa'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-protect-item  .pro-content  .pro-button .pro-button-wapper .elementor-button:hover .elementor-button-icon i' => 'fill: {{VALUE}}; color: {{VALUE}};',
                ],

            ]
        );
        $this->end_controls_tab();
        $this->end_controls_tabs();

        $this->add_responsive_control(
            'button_padding',
            [
                'label'      => esc_html__('Padding', 'ecofa'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .elementor-protect-item  .pro-content  .pro-button .pro-button-wapper .elementor-button' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
                ],
            ]
        );

        $this->add_responsive_control(
            'button_margin',
            [
                'label'      => esc_html__('Margin', 'ecofa'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .elementor-protect-item  .pro-content  .pro-button .pro-button-wapper .elementor-button' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}}',
                ],
            ]
        );
        $this->end_controls_section();
        // Carousel column
        $this->get_controls_column();
        // Carousel options
        $this->get_control_carousel();
    }
    protected function render(Widget_Base $instance = null) {
        if ( empty( $instance ) ) {
            $instance = $this;
        }
        $wrapper_tag     = 'div';
        $button_tag      = 'a';
        $animation_class = '';
        $settings = $instance->get_settings_for_display();
        $has_icon = !empty($settings['button_icon']);
        $migrated = isset( $settings['__fa4_migrated']['selected_icon'] );
        $is_new = empty( $settings['icon'] ) && Icons_Manager::is_migration_allowed();
        if ( ! $is_new && empty( $settings['icon_align'] ) ) {
            $settings['icon_align'] = $instance->get_settings( 'icon_align' );
        }
        $instance->add_render_attribute( [
            'icon-align' => [
                'class' => [
                    'elementor-button-icon',
                    'elementor-align-icon-' . $settings['icon_align'],
                ],
            ],
        ] );
        $this->add_render_attribute('button', 'class', [
            'elementor-button',
        ]);
        if (!empty($settings['link']['url'])) {
            $link_element = 'button';

            if ('box' === $settings['link_click']) {
                $wrapper_tag  = 'a';
                $button_tag   = 'span';
                $link_element = 'wrapper';
            }

            $this->add_link_attributes($link_element, $settings['link']);
        }
        $this->add_inline_editing_attributes('button');
        if (!empty($settings['protect']) && is_array($settings['protect'])) {
            $this->get_data_elementor_columns();
            $this->add_render_attribute('wrapper', 'class', 'elementor-protect-wrapper');
            $this->add_render_attribute('item', 'class', 'elementor-protect-item');
            if ( ! empty( $settings['link']['url'] ) ) {
                $button_tag = 'a';
                $this->add_link_attributes( 'link', $settings['link'] );
            }
            ?>
           <div <?php $this->print_render_attribute_string('wrapper'); // WPCS: XSS ok. ?>>
                <div <?php $this->print_render_attribute_string('container'); ?>>
                    <div <?php $this->print_render_attribute_string('inner'); // WPCS: XSS ok. ?>>
                        <?php foreach ($settings['protect'] as $protect): ?>
                            <div <?php $this->print_render_attribute_string('item'); // WPCS: XSS ok. ?>>
                                <?php $this->render_image($settings, $protect); ?>
                                <div class="pro-content">
                                    <div class="pro-title"><?php echo esc_html($protect['protect_title']);?></div>
                                    <div class="pro-subtitle"><?php echo esc_html($protect['protect_sub_title']);?></div>
                                    <div class="pro-button">
                                        <?php if (!empty($settings['button'])) : ?>
                                             <div class="pro-button-wapper<?php echo esc_attr($animation_class); ?>">
                                                 <<?php echo esc_html($button_tag) . ' ' . $this->get_render_attribute_string('button'); ?>>
                                                 <span class="elementor-button-content-wrapper">
                                                    <?php if ( ! empty( $settings['icon'] ) || ! empty( $settings['selected_icon']['value'] ) ) : ?>
                                                        <span <?php $instance->print_render_attribute_string( 'icon-align' ); ?>>
                                                            <?php if ( $is_new || $migrated ) :
                                                                Icons_Manager::render_icon( $settings['selected_icon'], [ 'aria-hidden' => 'true' ] );
                                                            else : ?>
                                                                <i class="<?php echo esc_attr( $settings['icon'] ); ?>" aria-hidden="true"></i>
                                                            <?php endif; ?>
                                                        </span>
                                                    <?php endif; ?>
                                                    <span class="elementor-button-text"><?php echo sprintf('%s', $settings['button']); ?></span>
                                                </span>
                                             </<?php echo esc_html($button_tag); ?>>
                                             </div>
                                        <?php endif; ?>
                                    </div>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    </div>
                </div>
               <?php $this->get_swiper_navigation(count($settings['protect'])); ?>
           </div>
            <?php
        }
    }
    private function render_image($settings, $protect)
    {
        if (!empty($protect['protect_image']['url'])) :
            ?>
            <div class="pro-image">
                <?php
                $protect['protect_image_size'] = $settings['protect_image_size'];
                $protect['protect_image_custom_dimension'] = $settings['protect_image_custom_dimension'];
                echo Group_Control_Image_Size::get_attachment_image_html($protect, 'protect_image');
                ?>
            </div>
        <?php
        endif;
    }
}
$widgets_manager->register(new Ecofa_Elementor_Protect());