<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Image_Size;
use Elementor\Repeater;
use Ecofa\Elementor\Ecofa_Base_Widgets;


class Ecofa_Elementor_Slider_Scrolling extends Ecofa_Base_Widgets {

    /**
     * Get widget name.
     *
     * Retrieve testimonial widget name.
     *
     * @return string Widget name.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_name() {
        return 'ecofa-slider-scrolling';
    }

    /**
     * Get widget title.
     *
     * Retrieve testimonial widget title.
     *
     * @return string Widget title.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_title() {
        return esc_html__('Ecofa Slider Scrolling', 'ecofa');
    }

    /**
     * Get widget icon.
     *
     * Retrieve testimonial widget icon.
     *
     * @return string Widget icon.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_icon() {
        return 'eicon-image';
    }

    public function get_script_depends() {
        return ['ecofa-elementor-slider-scrolling'];
    }

    public function get_categories() {
        return array('ecofa-addons');
    }

    /**
     * Register testimonial widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(
            'section_slider_scrolling',
            [
                'label' => esc_html__('Slider Scrolling', 'ecofa'),
            ]
        );
        $repeater = new Repeater();
        $repeater->add_control(
            'scrolling_title',
            [
                'label'   => esc_html__('Title 1', 'ecofa'),
                'type'    => Controls_Manager::TEXT,
                'default' => 'Scrolling title',
            ]
        );
        $repeater->add_control(
            'scrolling_title_link',
            [
                'label'       => esc_html__('Link to', 'ecofa'),
                'placeholder' => esc_html__('https://your-link.com', 'ecofa'),
                'type'        => Controls_Manager::URL,
            ]
        );
        $this->add_control(
            'slider_scrolling',
            [
                'label'       => esc_html__('Items', 'ecofa'),
                'type'        => Controls_Manager::REPEATER,
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{{ scrolling_title }}}',
            ]
        );
        $this->end_controls_section();
        $this->start_controls_section(
            'section_style_slider_scrolling_wrapper',
            [
                'label' => esc_html__('Wrapper', 'ecofa'),
                'tab' => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_responsive_control(
            'slider_scrolling_padding',
            [
                'label' => esc_html__('Padding', 'ecofa'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .elementor-slider-scrolling-inner' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'slider_scrolling_margin',
            [
                'label' => esc_html__('Margin', 'ecofa'),
                'type' => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors' => [
                    '{{WRAPPER}} .elementor-slider-scrolling-inner' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_control(
            'slider_scrolling_background_color',
            [
                'label' => esc_html__('Background Color', 'ecofa'),
                'type' => Controls_Manager::COLOR,
                'default' => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-slider-scrolling-inner' => 'background-color: {{VALUE}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_style_slider_scrolling_title',
            [
                'label' => esc_html__('Title', 'ecofa'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_control(
            'slider_scrollingtitle_color',
            [
                'label'     => esc_html__('Color', 'ecofa'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-slider-scrolling-inner .elementor-slider-scrolling-item .elementor-scrolling-item-inner .scrolling-title .title-scrolling a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'title_typography',
                'selector' => '{{WRAPPER}} .elementor-slider-scrolling-inner .elementor-slider-scrolling-item .elementor-scrolling-item-inner .scrolling-title .title-scrolling',
            ]
        );

        $this->add_responsive_control(
            'slider_scrolling_title_margin',
            [
                'label'      => esc_html__('Margin', 'ecofa'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .elementor-slider-scrolling-inner .elementor-slider-scrolling-item .elementor-scrolling-item-inner .scrolling-title ' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',

                ],
            ]
        );
        $this->end_controls_section();
    }

    protected function render() {
        $settings = $this->get_settings_for_display();
        if (!empty($settings['slider_scrolling']) && is_array($settings['slider_scrolling'])) {
            $this->add_render_attribute('wrapper', 'class', 'elementor-slider-scrolling-item-wrapper');
            $this->add_render_attribute('inner', 'class', 'elementor-slider-scrolling-inner');
            // Item
            $this->add_render_attribute('item', 'class', 'elementor-slider-scrolling-item');
            ?>
            <div <?php $this->print_render_attribute_string('wrapper'); ?>>
                <?php
                for ($i = 0; $i <= 3; $i++) {
                    ?>
                    <div <?php $this->print_render_attribute_string('inner'); ?>>
                        <?php foreach ($settings['slider_scrolling'] as $item) : ?>
                            <div <?php $this->print_render_attribute_string('item'); ?>>
                                <div class="elementor-scrolling-item-inner">
                                    <div class="scrolling-title">
                                        <?php
                                        $scrolling_title_html = $item['scrolling_title'];
                                        if (!empty($item['scrolling_title_link']['url'])) :
                                            $scrolling_title_html = '<a href="' . esc_url($item['scrolling_title_link']['url']) . '">' . esc_html($scrolling_title_html) . '</a>';
                                        endif;
                                        printf('<span class="title-scrolling">%s</span>', $scrolling_title_html);
                                        ?>
                                    </div>
                                </div>
                            </div>
                        <?php endforeach; ?>
                    </div>
                    <?php
                }
                ?>
            </div>
            <?php
        }
    }
}
$widgets_manager->register(new Ecofa_Elementor_Slider_Scrolling());