<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

use Elementor\Controls_Manager;
use Elementor\Group_Control_Typography;
use Elementor\Group_Control_Border;
use Elementor\Group_Control_Box_Shadow;
use Elementor\Group_Control_Image_Size;
use Elementor\Repeater;
use Ecofa\Elementor\Ecofa_Base_Widgets;


class Ecofa_Elementor_Testimonials_Carousel extends Ecofa_Base_Widgets {

    /**
     * Get widget name.
     *
     * Retrieve testimonial widget name.
     *
     * @return string Widget name.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_name() {
        return 'ecofa-testimonials-carousel';
    }

    /**
     * Get widget title.
     *
     * Retrieve testimonial widget title.
     *
     * @return string Widget title.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_title() {
        return esc_html__('Ecofa Testimonials Carousel', 'ecofa');
    }

    /**
     * Get widget icon.
     *
     * Retrieve testimonial widget icon.
     *
     * @return string Widget icon.
     * @since  1.0.0
     * @access public
     *
     */
    public function get_icon() {
        return 'eicon-testimonial';
    }

    public function get_script_depends() {
        return ['ecofa-elementor-testimonial-carousel'];
    }

    public function get_categories() {
        return array('ecofa-addons');
    }

    /**
     * Register testimonial widget controls.
     *
     * Adds different input fields to allow the user to change and customize the widget settings.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function register_controls() {
        $this->start_controls_section(
            'section_testimonial_carousel',
            [
                'label' => esc_html__('Testimonials', 'ecofa'),
            ]
        );
        $repeater = new Repeater();
        $repeater->add_control(
            'testimonial_carousel_image',
            [
                'label'      => esc_html__('Choose Image', 'ecofa'),
                'type'       => Controls_Manager::MEDIA,
                'show_label' => false,
            ]
        );
        $repeater->add_control(
            'testimonial_carousel_title',
            [
                'label'   => esc_html__('Title', 'ecofa'),
                'type'    => Controls_Manager::TEXT,
                'default' => 'Testimonial title',
            ]
        );

        $repeater->add_control(
            'testimonial_carousel_rating',
            [
                'label'   => esc_html__('Rating', 'ecofa'),
                'default' => 5,
                'type'    => Controls_Manager::SELECT,
                'options' => [
                    0 => esc_html__('Hidden', 'ecofa'),
                    1 => esc_html__('Very poor', 'ecofa'),
                    2 => esc_html__('Not that bad', 'ecofa'),
                    3 => esc_html__('Average', 'ecofa'),
                    4 => esc_html__('Good', 'ecofa'),
                    5 => esc_html__('Perfect', 'ecofa'),
                ]
            ]
        );
        $repeater->add_control(
            'testimonial_carousel_content',
            [
                'label'       => esc_html__('Content', 'ecofa'),
                'type'        => Controls_Manager::TEXTAREA,
                'default'     => 'Click edit button to change this text. Lorem ipsum dolor sit amet, consectetur adipiscing elit. Ut elit tellus, luctus nec ullamcorper mattis, pulvinar dapibus leo.',
                'label_block' => true,
                'rows'        => '10',
            ]
        );

        $repeater->add_control(
            'testimonial_carousel_name',
            [
                'label'   => esc_html__('Name', 'ecofa'),
                'default' => 'John Doe',
                'type'    => Controls_Manager::TEXT,
            ]
        );

        $repeater->add_control(
            'testimonial_carousel_job',
            [
                'label'   => esc_html__('Job', 'ecofa'),
                'default' => 'Design',
                'type'    => Controls_Manager::TEXT,
            ]
        );

        $repeater->add_control(
            'testimonial_carousel_avatar',
            [
                'label'      => esc_html__('Choose Avatar', 'ecofa'),
                'type'       => Controls_Manager::MEDIA,
                'show_label' => false,
            ]
        );

        $repeater->add_control(
            'testimonial_carousel_link',
            [
                'label'       => esc_html__('Link to', 'ecofa'),
                'placeholder' => esc_html__('https://your-link.com', 'ecofa'),
                'type'        => Controls_Manager::URL,
            ]
        );

        $this->add_control(
            'testimonials_carousel',
            [
                'label'       => esc_html__('Items', 'ecofa'),
                'type'        => Controls_Manager::REPEATER,
                'fields'      => $repeater->get_controls(),
                'title_field' => '{{{ testimonial_carousel_name }}}',
            ]
        );

        $this->add_group_control(
            Elementor\Group_Control_Image_Size::get_type(),
            [
                'name'      => 'testimonial_carousel_image', 'testimonial_carousel_avatar',
                'default'   => 'full',
                'separator' => 'none',
            ]
        );
        $this->end_controls_section();
        $this->start_controls_section(
            'section_style_testimonial_carousel_wrapper',
            [
                'label' => esc_html__('Wrapper', 'ecofa'),
                'tab'   => Controls_Manager::TAB_STYLE,

            ]
        );
        $this->add_responsive_control(
            'padding_testimonial_carousel_wrapper',
            [
                'label'      => esc_html__('Padding', 'ecofa'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} ' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'margin_testimonial_carousel_wrapper',
            [
                'label'      => esc_html__('Margin', 'ecofa'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} ' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->end_controls_section();
        $this->start_controls_section(
            'section_style_testimonial_carousel_img',
            [
                'label' => esc_html__('Image', 'ecofa'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_responsive_control(
            'testimonial_carousel_width_img',
            [
                'label'      => esc_html__('Width', 'ecofa'),
                'type'       => Controls_Manager::SLIDER,
                'range'      => [
                    'px' => [
                        'min' => 100,
                        'max' => 1000,
                    ],
                    'vh' => [
                        'min' => 10,
                        'max' => 100,
                    ],
                ],
                'size_units' => ['px', '%', 'vw'],
                'selectors'  => [
                    '{{WRAPPER}} .elementor-testimonials-carousel-item .testimonials-carousel-column-left .testimonial-carousel-image .elementor-testimonial-image img' => 'width: {{SIZE}}{{UNIT}}',
                ],
            ]
        );
        $this->add_responsive_control(
            'testimonial_carousel_height_img',
            [
                'label'      => esc_html__('Height', 'ecofa'),
                'type'       => Controls_Manager::SLIDER,
                'range'      => [
                    'px' => [
                        'min' => 100,
                        'max' => 1000,
                    ],
                    'vh' => [
                        'min' => 10,
                        'max' => 100,
                    ],
                ],
                'size_units' => ['px', 'vh'],
                'selectors'  => [
                    '{{WRAPPER}} .elementor-testimonials-carousel-item .testimonials-carousel-column-left .testimonial-carousel-image .elementor-testimonial-image img' => 'height: {{SIZE}}{{UNIT}}',
                ],
            ]
        );
        $this->add_control(
            'testimonial_carousel_radius_img',
            [
                'label'      => esc_html__('Border Radius', 'ecofa'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .elementor-testimonials-carousel-item .testimonials-carousel-column-left .testimonial-carousel-image .elementor-testimonial-image img' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'padding_testimonial_carousel_img',
            [
                'label'      => esc_html__('Padding', 'ecofa'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .elementor-testimonials-carousel-item .testimonials-carousel-column-left .testimonial-carousel-image .elementor-testimonial-image' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'margin_testimonial_carousel_img',
            [
                'label'      => esc_html__('Margin', 'ecofa'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .elementor-testimonials-carousel-item .testimonials-carousel-column-left .testimonial-carousel-image .elementor-testimonial-image' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->end_controls_section();
        $this->start_controls_section(
            'section_style_testimonial',
            [
                'label' => esc_html__('Testimonial', 'ecofa'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );
        $this->add_responsive_control(
            'padding_testimonial',
            [
                'label'      => esc_html__('Padding', 'ecofa'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .elementor-testimonials-carousel-item-wrapper .elementor-testimonials-carousel-item .testimonials-carousel-column-right .testimonial' => 'padding: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'margin_testimonial',
            [
                'label'      => esc_html__('Margin', 'ecofa'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em'],
                'selectors'  => [
                    '{{WRAPPER}} .elementor-testimonials-carousel-item-wrapper .elementor-testimonials-carousel-item .testimonials-carousel-column-right .testimonial' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->add_control(
            'color_testimonial-carousel_background',
            [
                'label'     => esc_html__('Background Color', 'ecofa'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-testimonials-carousel-item-wrapper .elementor-testimonials-carousel-item .testimonials-carousel-column-right .testimonial' => 'background: {{VALUE}};',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Box_Shadow::get_type(),
            [
                'name'     => 'testimonial_box-shadow',
                'selector' => '{{WRAPPER}} .elementor-testimonials-carousel-item-wrapper .elementor-testimonials-carousel-item .testimonials-carousel-column-right .testimonial',
            ]
        );
        $this->add_responsive_control(
            'testimonial_carousel_alignment',
            [
                'label'       => esc_html__('Alignment Content', 'ecofa'),
                'type'        => Controls_Manager::CHOOSE,
                'options'     => [
                    'left'   => [
                        'title' => esc_html__('Left', 'ecofa'),
                        'icon'  => 'eicon-text-align-left',
                    ],
                    'center' => [
                        'title' => esc_html__('Center', 'ecofa'),
                        'icon'  => 'eicon-text-align-center',
                    ],
                    'right'  => [
                        'title' => esc_html__('Right', 'ecofa'),
                        'icon'  => 'eicon-text-align-right',
                    ],
                ],
                'label_block' => false,
                'selectors'   => [
                    '{{WRAPPER}} .elementor-testimonials-carousel-item-wrapper .elementor-testimonials-carousel-item .testimonials-carousel-column-right .testimonial' => 'text-align: {{VALUE}};',
                ],
            ]
        );
        $this->add_responsive_control(
            'align_caption',
            [
                'label'     => esc_html__('Alignment Info ', 'ecofa'),
                'type'      => Controls_Manager::CHOOSE,
                'options'   => [
                    'flex-start' => [
                        'title' => esc_html__('Left', 'ecofa'),
                        'icon'  => 'eicon-h-align-left',
                    ],
                    'center'     => [
                        'title' => esc_html__('Center', 'ecofa'),
                        'icon'  => 'eicon-h-align-center',
                    ],
                    'flex-end'   => [
                        'title' => esc_html__('Right', 'ecofa'),
                        'icon'  => 'eicon-h-align-right',
                    ],
                ],
                'default'   => 'flex-start',
                'selectors' => [
                    '{{WRAPPER}} .elementor-testimonials-carousel-item-wrapper .elementor-testimonials-carousel-item .testimonials-carousel-column-right .testimonial .testimonial-caption ' => 'justify-content: {{VALUE}}',
                ],
            ]
        );
        $this->add_group_control(
            Group_Control_Border::get_type(),
            [
                'name'        => 'wrapper_border',
                'placeholder' => '1px',
                'default'     => '1px',
                'selector'    => '{{WRAPPER}} .elementor-testimonials-carousel-item-wrapper .elementor-testimonials-carousel-item .testimonials-carousel-column-right .testimonial',
                'separator'   => 'before',

            ]
        );

        $this->add_control(
            'wrapper_radius',
            [
                'label'      => esc_html__('Border Radius', 'ecofa'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .elementor-testimonials-carousel-item-wrapper .elementor-testimonials-carousel-item .testimonials-carousel-column-right .testimonial' => 'border-radius: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );
        $this->end_controls_section();
        $this->start_controls_section(
            'section_style_testimonial_carousel_style',
            [
                'label' => esc_html__('Content', 'ecofa'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'testimonial_carousel_content_color',
            [
                'label'     => esc_html__('Color', 'ecofa'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-testimonials-carousel-item-wrapper .elementor-testimonials-carousel-item .testimonials-carousel-column-right .testimonial .content' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'testimonial_carousel_content_color_hover',
            [
                'label'     => esc_html__('Color Hover', 'ecofa'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-testimonials-carousel-item-wrapper .elementor-testimonials-carousel-item .testimonials-carousel-column-right .testimonial:hover .content' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'content_typography',
                'selector' => '{{WRAPPER}} .elementor-testimonials-carousel-item-wrapper .elementor-testimonials-carousel-item .testimonials-carousel-column-right .testimonial .content',
            ]
        );

        $this->add_responsive_control(
            'testimonial_carousel_content_spacing',
            [
                'label'      => esc_html__('Margin', 'ecofa'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .elementor-testimonials-carousel-item-wrapper .elementor-testimonials-carousel-item .testimonials-carousel-column-right .testimonial .content' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();

        $this->start_controls_section(
            'section_style_testimonial_carousel_name',
            [
                'label' => esc_html__('Name', 'ecofa'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'testimonial_carousel_name_text_color',
            [
                'label'     => esc_html__('Color', 'ecofa'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-testimonials-carousel-item-wrapper .elementor-testimonials-carousel-item .testimonials-carousel-column-right .testimonial .testimonial-caption .caption-top .name, {{WRAPPER}} .name a' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'testimonial_carousel_name_text_color_hover',
            [
                'label'     => esc_html__('Color Hover', 'ecofa'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-testimonials-carousel-item-wrapper .elementor-testimonials-carousel-item .testimonials-carousel-column-right .testimonial .testimonial-caption .caption-top .name:hover, {{WRAPPER}} .inner .name a:hover' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'name_typography',
                'selector' => '{{WRAPPER}} .elementor-testimonials-carousel-item-wrapper .elementor-testimonials-carousel-item .testimonials-carousel-column-right .testimonial .testimonial-caption .caption-top .name',
            ]
        );

        $this->end_controls_section();

        // Job.
        $this->start_controls_section(
            'section_style_testimonial_carousel_job',
            [
                'label' => esc_html__('Job', 'ecofa'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'testimonial_carousel_job_text_color',
            [
                'label'     => esc_html__('Color', 'ecofa'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-testimonials-carousel-item-wrapper .elementor-testimonials-carousel-item .testimonials-carousel-column-right .testimonial .testimonial-caption .caption-top .job' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_control(
            'testimonial_carousel_job_text_color_hover',
            [
                'label'     => esc_html__('Color Hover', 'ecofa'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-testimonials-carousel-item-wrapper .elementor-testimonials-carousel-item .testimonials-carousel-column-right .testimonial .testimonial-caption .caption-top .job:hover' => 'color: {{VALUE}};',
                ],
            ]
        );


        $this->add_group_control(
            Group_Control_Typography::get_type(),
            [
                'name'     => 'job_typography',
                'selector' => '{{WRAPPER}} .elementor-testimonials-carousel-item-wrapper .elementor-testimonials-carousel-item .testimonials-carousel-column-right .testimonial .testimonial-caption .caption-top .job',
            ]
        );

        $this->end_controls_section();

        // rating
        $this->start_controls_section(
            'section_style_testimonial_carousel_rating',
            [
                'label' => esc_html__('Rating', 'ecofa'),
                'tab'   => Controls_Manager::TAB_STYLE,
            ]
        );

        $this->add_control(
            'testimonial_carousel_rating_color',
            [
                'label'     => esc_html__('Color', 'ecofa'),
                'type'      => Controls_Manager::COLOR,
                'default'   => '',
                'selectors' => [
                    '{{WRAPPER}} .elementor-testimonials-carousel-item-wrapper .elementor-testimonials-carousel-item .testimonials-carousel-column-right .testimonial .testimonial-carousel-rating .elementor-testimonial-carousel-rating' => 'color: {{VALUE}};',
                ],
            ]
        );

        $this->add_responsive_control(
            'testimonial_carousel_rating_spacing',
            [
                'label'      => esc_html__('Margin', 'ecofa'),
                'type'       => Controls_Manager::DIMENSIONS,
                'size_units' => ['px', 'em', '%'],
                'selectors'  => [
                    '{{WRAPPER}} .elementor-testimonials-carousel-item-wrapper .elementor-testimonials-carousel-item .testimonials-carousel-column-right .testimonial .testimonial-carousel-rating' => 'margin: {{TOP}}{{UNIT}} {{RIGHT}}{{UNIT}} {{BOTTOM}}{{UNIT}} {{LEFT}}{{UNIT}};',
                ],
            ]
        );

        $this->end_controls_section();
    }

    /**
     * Render testimonial widget output on the frontend.
     *
     * Written in PHP and used to generate the final HTML.
     *
     * @since  1.0.0
     * @access protected
     */
    protected function render() {
        $settings = $this->get_settings_for_display();
        if (!empty($settings['testimonials_carousel']) && is_array($settings['testimonials_carousel'])) {
            $this->add_render_attribute('wrapper', 'class', 'elementor-testimonials-carousel-item-wrapper');
//            $this->get_data_elementor_columns();
            $this->add_render_attribute('wrapper', 'class', 'ecofa-swiper-testimonials-carousel-wrapper swiper-1');
            $this->add_render_attribute('container', 'class', ['swiper', 'ecofa-testimonials-carousel-swiper']);
            $this->add_render_attribute('inner', 'class', 'swiper-wrapper');
            $this->add_render_attribute('item', 'class', 'swiper-slide elementor-testimonials-carousel-item');
            $this->add_render_attribute('details', 'class', 'details');
            ?>
            <div <?php $this->print_render_attribute_string('wrapper'); ?>>
                <div <?php $this->print_render_attribute_string('container'); ?>>
                    <div <?php $this->print_render_attribute_string('inner'); ?>>
                        <?php foreach ($settings['testimonials_carousel'] as $item): ?>
                        <div <?php $this->print_render_attribute_string('item'); ?>>
                            <div class="testimonials-carousel-column-left">
                                <div class="testimonial-carousel-image">
                                    <?php $this->render_image($settings, $item); ?>
                                </div>
                            </div>
                            <div class="testimonials-carousel-column-right">
                                <div class="testimonial">
                                    <div class="testimonial-carousel-rating">
                                        <?php $this->render_rating($item); ?>
                                    </div>
                                    <?php if (!empty($item['testimonial_carousel_content'])) : ?>
                                        <div class="content"><?php echo sprintf('%s', $item['testimonial_carousel_content']); ?></div>
                                    <?php endif; ?>
                                    <div class="testimonial-caption">
                                        <div class="testimonial-carousel-avatar">
                                            <?php $this->render_avatar($settings, $item); ?>
                                        </div>
                                        <div class="caption-top">
                                            <?php
                                            $testimonial_carousel_name_html = $item['testimonial_carousel_name'];
                                            if (!empty($item['testimonial_carousel_link']['url'])) :
                                                $testimonial_carousel_name_html = '<a href="' . esc_url($item['testimonial_carousel_link']['url']) . '">' . esc_html($testimonial_carousel_name_html) . '</a>';
                                            endif;
                                            printf('<span class="name">%s</span>', $testimonial_carousel_name_html);
                                            ?>
                                            <div <?php $this->print_render_attribute_string('details'); ?>>
                                                <?php if ($item['testimonial_carousel_job']): ?>
                                                    <span class="job"><?php echo esc_html($item['testimonial_carousel_job']); ?></span>
                                                <?php endif; ?>
                                            </div>
                                        </div>
                                    </div>
                                </div>
                            </div>
                        </div>
                        <?php endforeach; ?>
                    </div>
                </div>
                <div class="swiper-pagination"></div>
            </div>
            <?php
        }
    }
    private function render_image($settings, $testimonials_carousel) {
        if (!empty($testimonials_carousel['testimonial_carousel_image']['url'])) :
            ?>
            <div class="elementor-testimonial-image">
                <?php
                $testimonials_carousel['testimonial_carousel_image_size']             = $settings['testimonial_carousel_image_size'];
                $testimonials_carousel['testimonial_carousel_image_custom_dimension'] = $settings['testimonial_carousel_image_custom_dimension'];
                echo Group_Control_Image_Size::get_attachment_image_html($testimonials_carousel, 'testimonial_carousel_image');
                ?>
            </div>
        <?php
        endif;

    }
    private function render_avatar($settings, $testimonials_carousel) {
        if (!empty($testimonials_carousel['testimonial_carousel_avatar']['url'])) :
            ?>
            <div class="elementor-testimonial-avatar">
                <?php
                $testimonials_carousel['testimonial_carousel_image_size']             = $settings['testimonial_carousel_image_size'];
                $testimonials_carousel['testimonial_carousel_image_custom_dimension'] = $settings['testimonial_carousel_image_custom_dimension'];
                echo Group_Control_Image_Size::get_attachment_image_html($testimonials_carousel, 'testimonial_carousel_avatar');
                ?>
            </div>
        <?php
        endif;
    }

    private function render_rating($testimonials_carousel) {
        if ($testimonials_carousel['testimonial_carousel_rating'] && $testimonials_carousel['testimonial_carousel_rating'] > 0) {
            echo '<div class="elementor-testimonial-carousel-rating">';
            for ($i = 1; $i <= 5; $i++) {
                if ($i <= $testimonials_carousel['testimonial_carousel_rating']) {
                    echo '<i class="ecofa-icon-rating active" aria-hidden="true"></i>';
                }
            }
            echo '</div>';
        }
    }
}
$widgets_manager->register(new Ecofa_Elementor_Testimonials_Carousel());

