<?php
if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

use Give\Helpers\Form\Utils as FormUtils;
use Give\Controller\Form as Form;

if (!class_exists('Ecofa_Give')) :

    class Ecofa_Give {
        public $installer;

        public function __construct() {
            add_action('widgets_init', array($this, 'init_sidebar'));
            add_filter('body_class', array($this, 'body_class'));
            add_filter('ecofa_theme_sidebar', array($this, 'set_sidebar'), 20);

            add_action('give_forms_category_add_form_fields', [$this, 'add_term_fields_color']);
            add_action('give_forms_category_edit_form_fields', [$this, 'edit_term_fields'], 10, 2);
            add_action('created_give_forms_category', [$this, 'save_term_fields']);
            add_action('edited_give_forms_category', [$this, 'save_term_fields']);

            add_action('admin_enqueue_scripts', [$this, 'enqueue_admin_script']);
            add_action('wp_enqueue_scripts', [$this, 'add_scripts'], 15);

//            add_filter('give-settings_get_settings_pages', [$this, 'give_settings_page_pages'], 0, 1);
            add_filter('give_forms_single_sidebar', 'ecofa_give_sidebar', 10, 1);

            add_action('give_before_single_form_summary', [$this, 'handleSingleDonationFormPage'], 10);

            add_action('give_embed_head', [$this, 'ecofa_give_embed_head']);

            $this->give_hooks_single();

        }

        public function give_hooks_single() {
            $form = new Form();
            remove_action('give_pre_form_output', 'give_form_content', 10, 2);
            add_action('give_single_form_summary', 'ecofa_single_give_summary_inner_start', 0);
            add_action('give_single_form_summary', 'give_show_form_images', 0);
            add_action('give_single_form_summary', 'ecofa_single_give_summary_right_start', 0);
            add_action('give_single_form_summary', 'ecofa_give_categories', 1);
            add_action('give_single_form_summary', 'ecofa_single_give_excerpt', 5);
            add_action('give_single_form_summary', 'ecofa_give_show_goal_progress', 5);
            add_action('give_single_form_summary', 'ecofa_single_give_summary_right_end', 5);
            add_action('give_single_form_summary', 'ecofa_single_give_summary_inner_end', 5);
            add_action('give_single_form_summary', 'ecofa_single_give_summary_tab', 5);
            add_action('give_single_form_summary', 'ecofa_single_give_content_start', 6);
            add_action('give_single_form_summary', 'ecofa_single_give_donation_title', 6);
            add_action('give_single_form_summary', 'ecofa_single_give_content_end', 190);


        }

        public function handleSingleDonationFormPage() {

            if (!FormUtils::isLegacyForm()) {
                add_action('ecofa_give_single_form_summary', 'give_template_single_title', 4);
                add_action('ecofa_give_single_form_summary', 'ecofa_give_meta', 5);
                add_action('ecofa_give_single_form_summary', 'give_show_form_images', 6);
                add_action('ecofa_give_single_form_summary', 'ecofa_single_give_summary_tab', 99);
                $form = new Form();
                add_action('give_after_single_form_summary', [$form, 'renderFormOnSingleDonationFormPage'], 1);
            }
        }

        public function ecofa_give_embed_head() {
            global $ecofa_version;
            wp_enqueue_style('ecofa-give-embed', get_template_directory_uri() . '/assets/css/give-embed.css', '', $ecofa_version);
        }

        public function body_class($classes) {
            if (give_is_setting_enabled(give_get_option('form_sidebar'))) {
                $classes[] = 'ecofa-give-single-form-sidebar-left';
            }
            if ('give_forms' === get_post_type()) {
                $classes = array_diff($classes, array(
                    'ecofa-sidebar-', 'ecofa-sidebar-left', 'ecofa-sidebar-right', 'ecofa-full-width-content', 'ecofa-content-width-wide'
                ));
                $sidebar = ecofa_get_theme_option('give_archive_sidebar', 'left');

                if ((is_post_type_archive('give_forms') || is_tax('give_forms_category') || is_tax('give_forms_tag')) && is_active_sidebar('sidebar-give-archive')) {
                    if ($sidebar == 'right') {
                        $classes[] = 'ecofa-sidebar-right';
                    } elseif ($sidebar == 'left') {
                        $classes[] = 'ecofa-sidebar-left';
                    } else {
                        $classes[] = 'ecofa-full-width-content';
                    }
                } else {
                    $classes[] = 'ecofa-full-width-content';
                }
            }
            return $classes;
        }

        public function set_sidebar($name) {

            if ('give_forms' === get_post_type()) {
                $name    = '';
                $sidebar = ecofa_get_theme_option('give_archive_sidebar', 'left');
                if ($sidebar != 'none') {
                    if ((is_post_type_archive('give_forms') || is_tax('give_forms_category') || is_tax('give_forms_tag')) && is_active_sidebar('sidebar-give-archive')) {
                        $name = 'sidebar-give-archive';
                    }
                }
            }
            return $name;
        }

        public function init_sidebar() {
            register_sidebar(array(
                'name'          => esc_html__('Give Archive Sidebar', 'ecofa'),
                'id'            => 'sidebar-give-archive',
                'description'   => esc_html__('Add widgets here to appear in your Give.', 'ecofa'),
                'before_widget' => '<div id="%1$s" class="widget %2$s ecofa-widget-give">',
                'after_widget'  => '</div>',
                'before_title'  => '<span class="gamma widget-title">',
                'after_title'   => '</span>',
            ));
        }

        public function add_term_fields_color($taxonomy) {

            ?>
            <div class="form-field">
                <label for="category-color"><?php echo esc_html__('Color', 'ecofa'); ?></label>
                <input type="text" name="_color" class="color-picker" id="category-color"/>
            </div>
            <?php
        }

        public function edit_term_fields($term, $taxonomy) {

            $value = get_term_meta($term->term_id, '_color', true);

            ?>
            <tr class="form-field">
                <th>
                    <label for="category-color"><?php echo esc_html__('Color', 'ecofa'); ?></label>
                </th>
                <td>
                    <input name="_color" id="category-color" class="color-picker" type="text" value="<?php echo esc_attr($value); ?>"/>
                </td>
            </tr>
            <?php

        }

        public function save_term_fields($term_id) {

            update_term_meta(
                $term_id,
                '_color',
                sanitize_text_field($_POST['_color'])
            );

        }

        public function enqueue_admin_script() {
            global $ecofa_version;

            $screen = get_current_screen();
            if ($screen->taxonomy == 'give_forms_category') {
                wp_enqueue_script('custtom-color-picker', get_theme_file_uri('assets/js/admin/colorpicker.js'), array(), $ecofa_version, true);

            }

        }

        public function add_scripts() {
            global $ecofa_version;

            wp_register_script('ecofa-processbar', get_template_directory_uri() . '/assets/js/give/progressbar.js', array('jquery'), $ecofa_version, true);
            wp_enqueue_script('ecofa-give-main', get_template_directory_uri() . '/assets/js/give/main.js', array('jquery'), $ecofa_version, true);

            wp_enqueue_style('ecofa-give', get_template_directory_uri() . '/assets/css/give.css', '', $ecofa_version);
            wp_style_add_data('ecofa-give', 'rtl', 'replace');
        }
    }
endif;

return new Ecofa_Give();