<?php

if (!class_exists('Ecofa_Give_gallery')) :
    class Ecofa_Give_gallery {
        public $installer;

        public function __construct() {
            add_action('add_meta_boxes', [$this, 'ecofa_give_view_meta'], 50);
            add_action('save_post_give_forms', [$this, 'ecofa_save_gallery_metabox'], 50, 2);
            add_action('admin_init', [$this, 'admin_init'], 100);
        }

        public function give_gallery_metabox_output($post) {
            ?>
            <div id="give_images_container">
                <ul class="give_images">
                    <?php
                    $give_image_gallery = array();

                    if (metadata_exists('post', $post->ID, '_give_image_gallery')) {
                        $give_image_gallery = get_post_meta($post->ID, '_give_image_gallery', true);
                    } else {
                        // Backwards compat
                        $attachment_ids     = get_posts('post_parent=' . $post->ID . '&numberposts=-1&post_type=attachment&orderby=menu_order&order=ASC&post_mime_type=image&fields=ids&meta_key=_woocommerce_360_image&meta_value=1');
                        $attachment_ids     = array_diff($attachment_ids, array(get_post_thumbnail_id()));
                        $give_image_gallery = implode(',', $attachment_ids);
                    }

                    $attachments         = array_filter(explode(',', $give_image_gallery));
                    $update_meta         = false;
                    $updated_gallery_ids = array();

                    if (!empty($attachments)) {
                        foreach ($attachments as $attachment_id) {
                            $attachment = wp_get_attachment_image($attachment_id, 'thumbnail');

                            // if attachment is empty skip
                            if (empty($attachment)) {
                                $update_meta = true;
                                continue;
                            }

                            echo '<li class="image" data-attachment_id="' . esc_attr($attachment_id) . '">
								' . $attachment . '
								<ul class="actions">
									<li><a href="#" class="delete tips" data-tip="' . esc_html__('Delete image', 'ecofa') . '">' . esc_html__('Delete', 'ecofa') . '</a></li>
								</ul>
							</li>';

                            // rebuild ids to be saved
                            $updated_gallery_ids[] = $attachment_id;
                        }

                        // need to update give meta to set new gallery ids
                        if ($update_meta) {
                            update_post_meta($post->ID, '_give_image_gallery', implode(',', $updated_gallery_ids));
                        }
                    }
                    ?>
                </ul>

                <input type="hidden" id="give_image_gallery" name="give_image_gallery" value="<?php echo esc_attr($give_image_gallery); ?>"/>

            </div>
            <p class="add_give_images hide-if-no-js">
                <a class="button" href="#" data-choose="<?php esc_attr_e('Add Gallery', 'ecofa'); ?>" data-update="<?php esc_attr_e('Add to gallery', 'ecofa'); ?>" data-delete="<?php esc_attr_e('Delete image', 'ecofa'); ?>" data-text="<?php esc_attr_e('Delete', 'ecofa'); ?>"><?php esc_html_e('Add gallery images', 'ecofa'); ?></a>
            </p>
            <?php

        }

        public function ecofa_give_view_meta() {
            add_meta_box('ecofa-give-gallery-images',
                esc_html__('Gallery images', 'ecofa'),
                [$this, 'give_gallery_metabox_output'],
                'give_forms', 'normal', 'high');
        }

        /**
         * ------------------------------------------------------------------------------------------------
         * Save metaboxes
         * ------------------------------------------------------------------------------------------------
         */
        public function ecofa_save_gallery_metabox($post_id, $post) {
            $attachment_ids = isset($_POST['give_image_gallery']) ? array_filter(explode(',', $_POST['give_image_gallery'])) : array();
            update_post_meta($post_id, '_give_image_gallery', implode(',', $attachment_ids));
        }

        public function admin_init() {
            global $ecofa_version;
            wp_enqueue_script('ecofa-give-gallery-admin-scripts', get_theme_file_uri('assets/js/admin/give-gallery.js'), array(), $ecofa_version, true);
            wp_enqueue_style('ecofa-give-gallery-admin-style', get_theme_file_uri('assets/css/admin/give-gallery.css'), '', $ecofa_version);
        }
    }

endif;
return new Ecofa_Give_gallery();



