<?php
function ecofa_give_form_grid_shortcode($atts) {

    $give_settings = give_get_settings();

    $atts = shortcode_atts(
        [
            'forms_per_page'           => 12,
            'paged'                    => true,
            'ids'                      => '',
            'exclude'                  => '',
            'orderby'                  => 'date',
            'order'                    => 'DESC',
            'cats'                     => '',
            'tags'                     => '',
            'columns'                  => '1',
            'show_title'               => true,
            'show_goal'                => true,
            'show_excerpt'             => true,
            'show_featured_image'      => true,
            'show_donate_button'       => true,
            'donate_button_text'       => '',
            'tag_background_color'     => '#69b868',
            'tag_text_color'           => '#333333',
            'donate_button_text_color' => '#000000',
            'image_size'               => 'medium',
            'image_height'             => 'auto',
            'excerpt_length'           => 16,
            'display_style'            => 'modal_reveal',
            'progress_bar_color'       => '#69b868',
            'status'                   => '', // open or closed.
            'style'                    => 'shortcode-form-grid'
        ],
        $atts
    );

    // Validate integer attributes.
    $atts['forms_per_page'] = intval($atts['forms_per_page']);
    $atts['excerpt_length'] = intval($atts['excerpt_length']);

    // Validate boolean attributes.
    $boolean_attributes = [
        'paged',
        'show_title',
        'show_goal',
        'show_excerpt',
        'show_featured_image',
    ];

    foreach ($boolean_attributes as $att) {
        $atts[$att] = filter_var($atts[$att], FILTER_VALIDATE_BOOLEAN);
    }

    // Set default form query args.
    $form_args = [
        'post_type'      => 'give_forms',
        'post_status'    => 'publish',
        'posts_per_page' => $atts['forms_per_page'],
        'orderby'        => $atts['orderby'],
        'order'          => $atts['order'],
        'paged'          => $atts['paged'],
        'tax_query'      => [
            'relation' => 'AND',
        ],
    ];

    // Filter results of form grid based on form status.
    $form_closed_status = trim($atts['status']);

    if (!empty($form_closed_status)) {
        $form_args['meta_query'] = [
            [
                'key'   => '_give_form_status',
                'value' => $form_closed_status,
            ],
        ];
    }

    // Maybe add pagination.
    if (true === $atts['paged']) {
        $form_args['paged'] = get_query_var('paged') ? get_query_var('paged') : 1;
    }

    // Maybe filter forms by IDs.
    if (!empty($atts['ids'])) {
        $form_args['post__in'] = array_filter(array_map('trim', explode(',', $atts['ids'])));
    }

    // Convert comma-separated form IDs into array.
    if (!empty($atts['exclude'])) {
        $form_args['post__not_in'] = array_filter(
            array_map(
                function ($item) {
                    return intval(trim($item));
                },
                explode(',', $atts['exclude'])
            )
        );
    }

    // Maybe filter by form category.
    if (!empty($atts['cats'])) {
        $cats = array_filter(array_map('trim', explode(',', $atts['cats'])));

        // Backward compatibility for term_ids.
        $term_ids = array_unique(array_filter($cats, 'is_numeric'));
        if ($term_ids) {
            $form_args['tax_query'][] = [
                'taxonomy' => 'give_forms_category',
                'terms'    => $term_ids,
            ];

        }

        $term_slug = array_unique(array_filter(array_diff($cats, $term_ids)));
        if ($term_slug) {
            $form_args['tax_query'][] = [
                'taxonomy' => 'give_forms_category',
                'field'    => 'slug',
                'terms'    => $term_slug,
            ];

        }
    }

    // Maybe filter by form tag.
    if (!empty($atts['tags'])) {
        $tags = array_filter(array_map('trim', explode(',', $atts['tags'])));

        // Backward compatibility for term_ids.
        $tag_ids = array_unique(array_filter($tags, 'is_numeric'));
        if ($tag_ids) {
            $form_args['tax_query'][] = [
                'taxonomy' => 'give_forms_tag',
                'terms'    => $tag_ids,
            ];

        }

        $tag_slug = array_unique(array_filter(array_diff($tags, $tag_ids)));
        if ($tag_slug) {
            $form_args['tax_query'][] = [
                'taxonomy' => 'give_forms_tag',
                'field'    => 'slug',
                'terms'    => $tag_slug,
            ];

        }
    }

    /**
     * Filter to modify WP Query for Total Goal.
     *
     * @param array $form_args WP query argument for Grid.
     *
     * @return array $form_args WP query argument for Grid.
     * @since 2.1.4
     *
     */
    $form_args = (array)apply_filters('give_form_grid_shortcode_query_args', $form_args);

    // Maybe filter by form Amount Donated or Number of Donations.
    switch ($atts['orderby']) {
        case 'amount_donated':
            $form_args['meta_key'] = '_give_form_earnings';
            $form_args['orderby']  = 'meta_value_num';
            break;
        case 'number_donations':
            $form_args['meta_key'] = '_give_form_sales';
            $form_args['orderby']  = 'meta_value_num';
            break;
        case 'random':
            $form_args['orderby'] = 'rand';
            break;
        case 'closest_to_goal':
            if (give_has_upgrade_completed('v240_update_form_goal_progress')) {
                $form_args['meta_key'] = '_give_form_goal_progress';
                $form_args['orderby']  = 'meta_value_num';
            }
            break;
    }

    // Query to output donation forms.
    $form_query = new WP_Query($form_args);

    if ($form_query->have_posts()) {
        ob_start();

        add_filter('add_give_goal_progress_class', 'add_give_goal_progress_class', 10, 1);
        add_filter('add_give_goal_progress_bar_class', 'add_give_goal_progress_bar_class', 10, 1);
        add_filter('give_form_wrap_classes', 'add_class_for_form_grid', 10, 3);
        add_action('give_donation_form_top', 'give_is_form_grid_page_hidden_field', 10, 3);

        echo '<div class="give-wrap">';
        echo '<div class="give-grid give-grid--' . esc_attr($atts['columns']) . '">';

        while ($form_query->have_posts()) {
            $form_query->the_post();

            // Give/templates/shortcode-form-grid.php.
            give_get_template($atts['style'], [$give_settings, $atts]);

        }

        wp_reset_postdata();

        echo '</div><!-- .give-grid -->';

        remove_filter('add_give_goal_progress_class', 'add_give_goal_progress_class');
        remove_filter('add_give_goal_progress_bar_class', 'add_give_goal_progress_bar_class');
        remove_filter('give_form_wrap_classes', 'add_class_for_form_grid', 10);
        remove_action('give_donation_form_top', 'give_is_form_grid_page_hidden_field', 10);

        if (false !== $atts['paged']) {
            $paginate_args = [
                'current'   => max(1, get_query_var('paged')),
                'total'     => $form_query->max_num_pages,
                'show_all'  => false,
                'end_size'  => 1,
                'mid_size'  => 2,
                'prev_next' => true,
                'prev_text' => __('&laquo; Previous', 'ecofa'),
                'next_text' => __('Next &raquo;', 'ecofa'),
                'type'      => 'plain',
                'add_args'  => false,
            ];

            printf(
                '<div class="give-page-numbers">%s</div>',
                paginate_links($paginate_args)
            );
        }
        echo '</div><!-- .give-wrap -->';

        return ob_get_clean();
    } // End if().
}

add_shortcode( 'ecofa_give_form_grid', 'ecofa_give_form_grid_shortcode' );