<?php
/**
 * The searchform.php template.
 *
 * Used any time that get_search_form() is called.
 *
 * @link https://developer.wordpress.org/reference/functions/wp_unique_id/
 * @link https://developer.wordpress.org/reference/functions/get_search_form/
 *
 * @package WordPress
 * @subpackage Twenty_Twenty_One
 * @since Twenty Twenty-One 1.0
 */

/*
 * Generate a unique ID for each form and a string containing an aria-label
 * if one was passed to get_search_form() in the args array.
 */
$ecofa_unique_id = wp_unique_id('search-form-');

$ecofa_aria_label = !empty($args['aria_label']) ? 'aria-label="' . esc_attr($args['aria_label']) . '"' : '';
?>
<form role="search" <?php printf('%s', $ecofa_aria_label) ?> method="get" class="search-form" action="<?php echo esc_url(home_url('/')); ?>">
    <label class="screen-reader-text" for="<?php echo esc_attr($ecofa_unique_id); ?>"><?php _e('Search&hellip;', 'ecofa'); // phpcs:ignore: WordPress.Security.EscapeOutput.UnsafePrintingFunction -- core trusts translations ?></label>
    <div class="wp-block-search__inside-wrapper">
        <input type="search" id="<?php echo esc_attr($ecofa_unique_id); ?>" class="search-field" value="<?php echo get_search_query(); ?>" name="s"/>
        <button type="submit" class="search-submit"><?php echo esc_attr_x('Search', 'submit button', 'ecofa'); ?></button>
    </div>
</form>
